"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6 import QtGui
from PyQt6 import QtCore
from PyQt6.QtWidgets import *
import enum


class QGraphicsBlurEffect(QGraphicsEffect):
    """
    https://doc.qt.io/qt-6/qgraphicsblureffect.html

    **Detailed Description**

    A blur effect blurs the source. This effect is useful for reducing details,
    such as when the source loses focus and you want to draw attention to other
    elements. The level of detail can be modified using the **setBlurRadius** ()
    function. Use **setBlurHints** () to choose the blur hints.

    By default, the blur radius is 5 pixels. The blur radius is specified in
    device coordinates.

    ![](images/graphicseffect-blur.png)

    **See also** **QGraphicsDropShadowEffect** , **QGraphicsColorizeEffect** ,
    and **QGraphicsOpacityEffect** .
    """

    class BlurHint(enum.Flag):
        PerformanceHint: QGraphicsBlurEffect = ...
        QualityHint: QGraphicsBlurEffect = ...
        AnimationHint: QGraphicsBlurEffect = ...

    def __init__(self, parent: typing.Optional[QtCore.QObject] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicsblureffect.html#QGraphicsBlurEffect

        **QGraphicsBlurEffect::QGraphicsBlurEffect(QObject * parent = nullptr)**

        Constructs a new QGraphicsBlurEffect instance. The **parent** parameter
        is passed to **QGraphicsEffect** 's constructor.
        """
        ...

    def draw(self, painter: QtGui.QPainter) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicsblureffect.html#draw

        **[override virtual protected] void QGraphicsBlurEffect::draw(QPainter *
        painter )**

        Reimplements: **QGraphicsEffect::draw** (QPainter *painter).
        """
        ...

    def setBlurHints(self, hints: "QGraphicsBlurEffect.BlurHint") -> None:
        """
        https://doc.qt.io/qt-6/qgraphicsblureffect.html#blurHints-prop

        **blurHints : BlurHints**

        This property holds the blur hint of the effect.

        Use the **PerformanceHint**  hint to say that you want a faster blur,
        the **QualityHint**  hint to say that you prefer a higher quality blur,
        or the **AnimationHint**  when you want to animate the blur radius.

        By default, the blur hint is **PerformanceHint** .

        **Access functions:**

        QGraphicsBlurEffect::BlurHints **blurHints** () const
        void
        **setBlurHints** (QGraphicsBlurEffect::BlurHints **hints** )

        **Notifier signal:**

        void ****blurHintsChanged** ** (QGraphicsBlurEffect::BlurHints **hints**
        )
        """
        ...

    def setBlurRadius(self, blurRadius: float) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicsblureffect.html#blurRadius-prop

        **blurRadius : qreal**

        This property holds the blur radius of the effect.

        Using a smaller radius results in a sharper appearance, whereas a bigger
        radius results in a more blurred appearance.

        By default, the blur radius is 5 pixels.

        The radius is given in device coordinates, meaning it is unaffected by
        scale.

        **Access functions:**

        qreal **blurRadius** () const
        void **setBlurRadius** (qreal
        **blurRadius** )

        **Notifier signal:**

        void ****blurRadiusChanged** ** (qreal **radius** )

        **Member Function Documentation**
        """
        ...

    def blurHints(self) -> "QGraphicsBlurEffect.BlurHint":
        """
        https://doc.qt.io/qt-6/qgraphicsblureffect.html#blurHints-prop

        **blurHints : BlurHints**

        This property holds the blur hint of the effect.

        Use the **PerformanceHint**  hint to say that you want a faster blur,
        the **QualityHint**  hint to say that you prefer a higher quality blur,
        or the **AnimationHint**  when you want to animate the blur radius.

        By default, the blur hint is **PerformanceHint** .

        **Access functions:**

        QGraphicsBlurEffect::BlurHints **blurHints** () const
        void
        **setBlurHints** (QGraphicsBlurEffect::BlurHints **hints** )

        **Notifier signal:**

        void ****blurHintsChanged** ** (QGraphicsBlurEffect::BlurHints **hints**
        )
        """
        ...

    def blurRadius(self) -> float:
        """
        https://doc.qt.io/qt-6/qgraphicsblureffect.html#blurRadius-prop

        **blurRadius : qreal**

        This property holds the blur radius of the effect.

        Using a smaller radius results in a sharper appearance, whereas a bigger
        radius results in a more blurred appearance.

        By default, the blur radius is 5 pixels.

        The radius is given in device coordinates, meaning it is unaffected by
        scale.

        **Access functions:**

        qreal **blurRadius** () const
        void **setBlurRadius** (qreal
        **blurRadius** )

        **Notifier signal:**

        void ****blurRadiusChanged** ** (qreal **radius** )

        **Member Function Documentation**
        """
        ...

    def boundingRectFor(self, rect: QtCore.QRectF) -> QtCore.QRectF:
        """
        https://doc.qt.io/qt-6/qgraphicsblureffect.html#boundingRectFor

        **[override virtual] QRectF QGraphicsBlurEffect::boundingRectFor(const
        QRectF & rect ) const**

        Reimplements: **QGraphicsEffect::boundingRectFor(const QRectF &rect)
        const** .
        """
        ...

    @property
    def blurHintsChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qgraphicsblureffect.html#blurHintsChanged

        **[signal] void
        QGraphicsBlurEffect::blurHintsChanged(QGraphicsBlurEffect::BlurHints
        hints )**

        This signal is emitted whenever the effect's blur hints changes. The
        **hints** parameter holds the effect's new blur hints.

        **Note:** Notifier signal for property **blurHints** .
        """
        ...

    @property
    def blurRadiusChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qgraphicsblureffect.html#blurRadiusChanged

        **[signal] void QGraphicsBlurEffect::blurRadiusChanged(qreal radius )**

        This signal is emitted whenever the effect's blur radius changes. The
        **radius** parameter holds the effect's new blur radius.

        **Note:** Notifier signal for property **blurRadius** .
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6 import QtWidgets


class QHelpSearchQueryWidget(QtWidgets.QWidget):
    """
    https://doc.qt.io/qt-6/qhelpsearchquerywidget.html

    **Detailed Description**
    """

    def __init__(self, parent: typing.Optional[QtWidgets.QWidget] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qhelpsearchquerywidget.html#QHelpSearchQueryWidge
        t

        **QHelpSearchQueryWidget::QHelpSearchQueryWidget(QWidget * parent =
        nullptr)**

        Constructs a new search query widget with the given **parent**.
        """
        ...

    def setSearchInput(self, searchInput: str) -> None:
        """
        https://doc.qt.io/qt-6/qhelpsearchquerywidget.html#setSearchInput

        **[since 5.9] void QHelpSearchQueryWidget::setSearchInput(const QString
        & searchInput )**

        Sets the **QHelpSearchQueryWidget**  input field to the value specified
        by **searchInput**.

        **Note:** The QHelpSearchEngine::search(const **QString**
        &**searchInput** ) function has to be called to perform the actual
        search.

        This function was introduced in Qt 5.9.

        **See also** **searchInput** ().
        """
        ...

    def searchInput(self) -> str:
        """
        https://doc.qt.io/qt-6/qhelpsearchquerywidget.html#searchInput

        **[since 5.9] QString QHelpSearchQueryWidget::searchInput() const**

        Returns a search phrase to use in combination with the
        QHelpSearchEngine::search(const **QString**  &searchInput) function.

        This function was introduced in Qt 5.9.

        **See also** **setSearchInput** ().
        """
        ...

    def setCompactMode(self, on: bool) -> None:
        ...

    def isCompactMode(self) -> bool:
        ...

    def collapseExtendedSearch(self) -> None:
        """
        https://doc.qt.io/qt-6/qhelpsearchquerywidget.html#collapseExtendedSearc
        h

        **void QHelpSearchQueryWidget::collapseExtendedSearch()**

        Collapses the search query widget so that only the default search field
        is shown.
        """
        ...

    def expandExtendedSearch(self) -> None:
        """
        https://doc.qt.io/qt-6/qhelpsearchquerywidget.html#expandExtendedSearch

        **void QHelpSearchQueryWidget::expandExtendedSearch()**

        Expands the search query widget so that the extended search fields are
        shown.
        """
        ...

    @property
    def search(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qhelpsearchquerywidget.html#search

        **[signal] void QHelpSearchQueryWidget::search()**

        This signal is emitted when a the user has the search button invoked.
        After receiving the signal you can ask the **QHelpSearchQueryWidget**
        for the search input that you may pass to the
        QHelpSearchEngine::search() function.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import PyQt6.sip
from PyQt6.QtGui import *
import enum


class QPaintDevice(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qpaintdevice.html

    **Detailed Description**

    A paint device is an abstraction of a two-dimensional space that can be
    drawn on using a **QPainter** . Its default coordinate system has its origin
    located at the top-left position. X increases to the right and Y increases
    downwards. The unit is one pixel.

    The drawing capabilities of QPaintDevice are currently implemented by the
    **QWidget** , **QImage** , **QPixmap** , **QPicture** , and **QPrinter**
    subclasses.

    To implement support for a new backend, you must derive from QPaintDevice
    and reimplement the virtual **paintEngine** () function to tell **QPainter**
    which paint engine should be used to draw on this particular device. Note
    that you also must create a corresponding paint engine to be able to draw on
    the device, i.e derive from **QPaintEngine**  and reimplement its virtual
    functions.

    **Warning:** Qt requires that a **QGuiApplication**  object exists before
    any paint devices can be created. Paint devices access window system
    resources, and these resources are not initialized before an application
    object is created.

    The QPaintDevice class provides several functions returning the various
    device metrics: The **depth** () function returns its bit depth (number of
    bit planes). The **height** () function returns its height in default
    coordinate system units (e.g. pixels for **QPixmap**  and **QWidget** )
    while **heightMM** () returns the height of the device in millimeters.
    Similiarily, the **width** () and **widthMM** () functions return the width
    of the device in default coordinate system units and in millimeters,
    respectively. Alternatively, the protected **metric** () function can be
    used to retrieve the metric information by specifying the desired
    **PaintDeviceMetric**  as argument.

    The **logicalDpiX** () and **logicalDpiY** () functions return the
    horizontal and vertical resolution of the device in dots per inch. The
    **physicalDpiX** () and **physicalDpiY** () functions also return the
    resolution of the device in dots per inch, but note that if the logical and
    physical resolution differ, the corresponding **QPaintEngine**  must handle
    the mapping. Finally, the **colorCount** () function returns the number of
    different colors available for the paint device.

    **See also** **QPaintEngine** , **QPainter** , **Coordinate System** , and
    **Paint System** .
    """

    class PaintDeviceMetric(enum.Enum):
        PdmWidth: QPaintDevice = ...
        PdmHeight: QPaintDevice = ...
        PdmWidthMM: QPaintDevice = ...
        PdmHeightMM: QPaintDevice = ...
        PdmNumColors: QPaintDevice = ...
        PdmDepth: QPaintDevice = ...
        PdmDpiX: QPaintDevice = ...
        PdmDpiY: QPaintDevice = ...
        PdmPhysicalDpiX: QPaintDevice = ...
        PdmPhysicalDpiY: QPaintDevice = ...
        PdmDevicePixelRatio: QPaintDevice = ...
        PdmDevicePixelRatioScaled: QPaintDevice = ...

    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qpaintdevice.html#QPaintDevice

        **[protected] QPaintDevice::QPaintDevice()**

        Constructs a paint device. This constructor can be invoked only from
        subclasses of QPaintDevice.
        """
        ...

    @staticmethod
    def devicePixelRatioFScale() -> float:
        ...

    def devicePixelRatioF(self) -> float:
        """
        https://doc.qt.io/qt-6/qpaintdevice.html#devicePixelRatioF

        **[since 5.6] qreal QPaintDevice::devicePixelRatioF() const**

        Returns the device pixel ratio for the device as a floating point
        number.

        This function was introduced in Qt 5.6.
        """
        ...

    def metric(self, metric: "QPaintDevice.PaintDeviceMetric") -> int:
        """
        https://doc.qt.io/qt-6/qpaintdevice.html#metric

        **[virtual protected] int
        QPaintDevice::metric(QPaintDevice::PaintDeviceMetric metric ) const**

        Returns the metric information for the given paint device **metric**.

        **See also** **PaintDeviceMetric** .
        """
        ...

    def devicePixelRatio(self) -> float:
        """
        https://doc.qt.io/qt-6/qpaintdevice.html#devicePixelRatio

        **qreal QPaintDevice::devicePixelRatio() const**

        Returns the device pixel ratio for device.

        Common values are 1 for normal-dpi displays and 2 for high-dpi "retina"
        displays.
        """
        ...

    def colorCount(self) -> int:
        """
        https://doc.qt.io/qt-6/qpaintdevice.html#colorCount

        **int QPaintDevice::colorCount() const**

        Returns the number of different colors available for the paint device.
        If the number of colors available is too great to be represented by the
        int data type, then INT_MAX will be returned instead.
        """
        ...

    def paintingActive(self) -> bool:
        """
        https://doc.qt.io/qt-6/qpaintdevice.html#paintingActive

        **bool QPaintDevice::paintingActive() const**

        Returns `true` if the device is currently being painted on, i.e. someone
        has called **QPainter::begin** () but not yet called **QPainter::end**
        () for this device; otherwise returns `false`.

        **See also** **QPainter::isActive** ().
        """
        ...

    def depth(self) -> int:
        """
        https://doc.qt.io/qt-6/qpaintdevice.html#depth

        **int QPaintDevice::depth() const**

        Returns the bit depth (number of bit planes) of the paint device.
        """
        ...

    def physicalDpiY(self) -> int:
        """
        https://doc.qt.io/qt-6/qpaintdevice.html#physicalDpiY

        **int QPaintDevice::physicalDpiY() const**

        Returns the horizontal resolution of the device in dots per inch. For
        example, when printing, this resolution refers to the physical printer's
        resolution. The logical DPI on the other hand, refers to the resolution
        used by the actual paint engine.

        Note that if the physicalDpiY() doesn't equal the **logicalDpiY** (),
        the corresponding **QPaintEngine**  must handle the resolution mapping.

        **See also** **physicalDpiX** () and **logicalDpiY** ().
        """
        ...

    def physicalDpiX(self) -> int:
        """
        https://doc.qt.io/qt-6/qpaintdevice.html#physicalDpiX

        **int QPaintDevice::physicalDpiX() const**

        Returns the horizontal resolution of the device in dots per inch. For
        example, when printing, this resolution refers to the physical printer's
        resolution. The logical DPI on the other hand, refers to the resolution
        used by the actual paint engine.

        Note that if the physicalDpiX() doesn't equal the **logicalDpiX** (),
        the corresponding **QPaintEngine**  must handle the resolution mapping.

        **See also** **physicalDpiY** () and **logicalDpiX** ().
        """
        ...

    def logicalDpiY(self) -> int:
        """
        https://doc.qt.io/qt-6/qpaintdevice.html#logicalDpiY

        **int QPaintDevice::logicalDpiY() const**

        Returns the vertical resolution of the device in dots per inch, which is
        used when computing font sizes. For X11, this is usually the same as
        could be computed from **heightMM** ().

        Note that if the logicalDpiY() doesn't equal the **physicalDpiY** (),
        the corresponding **QPaintEngine**  must handle the resolution mapping.

        **See also** **logicalDpiX** () and **physicalDpiY** ().
        """
        ...

    def logicalDpiX(self) -> int:
        """
        https://doc.qt.io/qt-6/qpaintdevice.html#logicalDpiX

        **int QPaintDevice::logicalDpiX() const**

        Returns the horizontal resolution of the device in dots per inch, which
        is used when computing font sizes. For X11, this is usually the same as
        could be computed from **widthMM** ().

        Note that if the logicalDpiX() doesn't equal the **physicalDpiX** (),
        the corresponding **QPaintEngine**  must handle the resolution mapping.

        **See also** **logicalDpiY** () and **physicalDpiX** ().
        """
        ...

    def heightMM(self) -> int:
        """
        https://doc.qt.io/qt-6/qpaintdevice.html#heightMM

        **int QPaintDevice::heightMM() const**

        Returns the height of the paint device in millimeters. Due to platform
        limitations it may not be possible to use this function to determine the
        actual physical size of a widget on the screen.

        **See also** **height** ().
        """
        ...

    def widthMM(self) -> int:
        """
        https://doc.qt.io/qt-6/qpaintdevice.html#widthMM

        **int QPaintDevice::widthMM() const**

        Returns the width of the paint device in millimeters. Due to platform
        limitations it may not be possible to use this function to determine the
        actual physical size of a widget on the screen.

        **See also** **width** ().
        """
        ...

    def height(self) -> int:
        """
        https://doc.qt.io/qt-6/qpaintdevice.html#height

        **int QPaintDevice::height() const**

        Returns the height of the paint device in default coordinate system
        units (e.g. pixels for **QPixmap**  and **QWidget** ).

        **See also** **heightMM** ().
        """
        ...

    def width(self) -> int:
        """
        https://doc.qt.io/qt-6/qpaintdevice.html#width

        **int QPaintDevice::width() const**

        Returns the width of the paint device in default coordinate system units
        (e.g. pixels for **QPixmap**  and **QWidget** ).

        **See also** **widthMM** ().
        """
        ...

    def paintEngine(self) -> "QPaintEngine":
        """
        https://doc.qt.io/qt-6/qpaintdevice.html#paintEngine

        **[pure virtual] QPaintEngine *QPaintDevice::paintEngine() const**

        Returns a pointer to the paint engine used for drawing on the device.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6 import QtCore
from PyQt6.QtGui import *
import enum


class QGradient(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qgradient.html

    **Detailed Description**

    Qt currently supports three types of gradient fills:

    * **Linear** gradients interpolate colors between start and end points.
      *
    **Simple** radial gradients interpolate colors between a focal point and end
    points on a circle surrounding it.
      * **Extended** radial gradients
    interpolate colors between a center and a focal circle.
      * **Conical**
    gradients interpolate colors around a center point.

    A gradient's type can be retrieved using the **type** () function. Each of
    the types is represented by a subclass of QGradient:

    **QLinearGradient** **QRadialGradient** **QConicalGradient**
    ![](images/qgradient-linear.png)![](images/qgradient-
    radial.png)![](images/qgradient-conical.png)

    The colors in a gradient are defined using stop points of the
    **QGradientStop**  type; i.e., a position and a color. Use the
    **setColorAt** () function to define a single stop point. Alternatively, use
    the **setStops** () function to define several stop points in one go. Note
    that the latter function **replaces** the current set of stop points.

    It is the gradient's complete set of stop points (accessible through the
    **stops** () function) that describes how the gradient area should be
    filled. If no stop points have been specified, a gradient of black at 0 to
    white at 1 is used.

    A diagonal linear gradient from black at (100, 100) to white at (200, 200)
    could be specified like this:

    **QLinearGradient**  linearGrad(**QPointF** (100, 100), **QPointF** (200,
    200));
        linearGrad.setColorAt(0, Qt::black);
        linearGrad.setColorAt(1,
    Qt::white);

    A gradient can have an arbitrary number of stop points. The following would
    create a radial gradient starting with red in the center, blue and then
    green on the edges:

    **QRadialGradient**  radialGrad(**QPointF** (100, 100), 100);
    radialGrad.setColorAt(0, Qt::red);
        radialGrad.setColorAt(0.5, Qt::blue);
    radialGrad.setColorAt(1, Qt::green);

    It is possible to repeat or reflect the gradient outside its area by
    specifying the **spread method**  using the **setSpread** () function. The
    default is to pad the outside area with the color at the closest stop point.
    The currently set **spread method**  can be retrieved using the **spread**
    () function. The **QGradient::Spread**  enum defines three different
    methods:

    ![](images/qradialgradient-pad.png)![](images/qradialgradient-
    repeat.png)![](images/qradialgradient-reflect.png)
    **PadSpread**
    **RepeatSpread** **ReflectSpread**

    Note that the **setSpread** () function only has effect for linear and
    radial gradients. The reason is that the conical gradient is closed by
    definition, i.e. the **conical** gradient fills the entire circle from 0 -
    360 degrees, while the boundary of a radial or a linear gradient can be
    specified through its radius or final stop points, respectively.

    The gradient coordinates can be specified in logical coordinates, relative
    to device coordinates, or relative to object bounding box coordinates. The
    **coordinate mode**  can be set using the **setCoordinateMode** () function.
    The default is **LogicalMode** , where the gradient coordinates are
    specified in the same way as the object coordinates. To retrieve the
    currently set **coordinate mode**  use **coordinateMode** ().

    **See also** **The Gradients Example**  and **QBrush** .
    """

    class Preset(enum.Enum):
        WarmFlame: QGradient = ...
        NightFade: QGradient = ...
        SpringWarmth: QGradient = ...
        JuicyPeach: QGradient = ...
        YoungPassion: QGradient = ...
        LadyLips: QGradient = ...
        SunnyMorning: QGradient = ...
        RainyAshville: QGradient = ...
        FrozenDreams: QGradient = ...
        WinterNeva: QGradient = ...
        DustyGrass: QGradient = ...
        TemptingAzure: QGradient = ...
        HeavyRain: QGradient = ...
        AmyCrisp: QGradient = ...
        MeanFruit: QGradient = ...
        DeepBlue: QGradient = ...
        RipeMalinka: QGradient = ...
        CloudyKnoxville: QGradient = ...
        MalibuBeach: QGradient = ...
        NewLife: QGradient = ...
        TrueSunset: QGradient = ...
        MorpheusDen: QGradient = ...
        RareWind: QGradient = ...
        NearMoon: QGradient = ...
        WildApple: QGradient = ...
        SaintPetersburg: QGradient = ...
        PlumPlate: QGradient = ...
        EverlastingSky: QGradient = ...
        HappyFisher: QGradient = ...
        Blessing: QGradient = ...
        SharpeyeEagle: QGradient = ...
        LadogaBottom: QGradient = ...
        LemonGate: QGradient = ...
        ItmeoBranding: QGradient = ...
        ZeusMiracle: QGradient = ...
        OldHat: QGradient = ...
        StarWine: QGradient = ...
        HappyAcid: QGradient = ...
        AwesomePine: QGradient = ...
        NewYork: QGradient = ...
        ShyRainbow: QGradient = ...
        MixedHopes: QGradient = ...
        FlyHigh: QGradient = ...
        StrongBliss: QGradient = ...
        FreshMilk: QGradient = ...
        SnowAgain: QGradient = ...
        FebruaryInk: QGradient = ...
        KindSteel: QGradient = ...
        SoftGrass: QGradient = ...
        GrownEarly: QGradient = ...
        SharpBlues: QGradient = ...
        ShadyWater: QGradient = ...
        DirtyBeauty: QGradient = ...
        GreatWhale: QGradient = ...
        TeenNotebook: QGradient = ...
        PoliteRumors: QGradient = ...
        SweetPeriod: QGradient = ...
        WideMatrix: QGradient = ...
        SoftCherish: QGradient = ...
        RedSalvation: QGradient = ...
        BurningSpring: QGradient = ...
        NightParty: QGradient = ...
        SkyGlider: QGradient = ...
        HeavenPeach: QGradient = ...
        PurpleDivision: QGradient = ...
        AquaSplash: QGradient = ...
        SpikyNaga: QGradient = ...
        LoveKiss: QGradient = ...
        CleanMirror: QGradient = ...
        PremiumDark: QGradient = ...
        ColdEvening: QGradient = ...
        CochitiLake: QGradient = ...
        SummerGames: QGradient = ...
        PassionateBed: QGradient = ...
        MountainRock: QGradient = ...
        DesertHump: QGradient = ...
        JungleDay: QGradient = ...
        PhoenixStart: QGradient = ...
        OctoberSilence: QGradient = ...
        FarawayRiver: QGradient = ...
        AlchemistLab: QGradient = ...
        OverSun: QGradient = ...
        PremiumWhite: QGradient = ...
        MarsParty: QGradient = ...
        EternalConstance: QGradient = ...
        JapanBlush: QGradient = ...
        SmilingRain: QGradient = ...
        CloudyApple: QGradient = ...
        BigMango: QGradient = ...
        HealthyWater: QGradient = ...
        AmourAmour: QGradient = ...
        RiskyConcrete: QGradient = ...
        StrongStick: QGradient = ...
        ViciousStance: QGradient = ...
        PaloAlto: QGradient = ...
        HappyMemories: QGradient = ...
        MidnightBloom: QGradient = ...
        Crystalline: QGradient = ...
        PartyBliss: QGradient = ...
        ConfidentCloud: QGradient = ...
        LeCocktail: QGradient = ...
        RiverCity: QGradient = ...
        FrozenBerry: QGradient = ...
        ChildCare: QGradient = ...
        FlyingLemon: QGradient = ...
        NewRetrowave: QGradient = ...
        HiddenJaguar: QGradient = ...
        AboveTheSky: QGradient = ...
        Nega: QGradient = ...
        DenseWater: QGradient = ...
        Seashore: QGradient = ...
        MarbleWall: QGradient = ...
        CheerfulCaramel: QGradient = ...
        NightSky: QGradient = ...
        MagicLake: QGradient = ...
        YoungGrass: QGradient = ...
        ColorfulPeach: QGradient = ...
        GentleCare: QGradient = ...
        PlumBath: QGradient = ...
        HappyUnicorn: QGradient = ...
        AfricanField: QGradient = ...
        SolidStone: QGradient = ...
        OrangeJuice: QGradient = ...
        GlassWater: QGradient = ...
        NorthMiracle: QGradient = ...
        FruitBlend: QGradient = ...
        MillenniumPine: QGradient = ...
        HighFlight: QGradient = ...
        MoleHall: QGradient = ...
        SpaceShift: QGradient = ...
        ForestInei: QGradient = ...
        RoyalGarden: QGradient = ...
        RichMetal: QGradient = ...
        JuicyCake: QGradient = ...
        SmartIndigo: QGradient = ...
        SandStrike: QGradient = ...
        NorseBeauty: QGradient = ...
        AquaGuidance: QGradient = ...
        SunVeggie: QGradient = ...
        SeaLord: QGradient = ...
        BlackSea: QGradient = ...
        GrassShampoo: QGradient = ...
        LandingAircraft: QGradient = ...
        WitchDance: QGradient = ...
        SleeplessNight: QGradient = ...
        AngelCare: QGradient = ...
        CrystalRiver: QGradient = ...
        SoftLipstick: QGradient = ...
        SaltMountain: QGradient = ...
        PerfectWhite: QGradient = ...
        FreshOasis: QGradient = ...
        StrictNovember: QGradient = ...
        MorningSalad: QGradient = ...
        DeepRelief: QGradient = ...
        SeaStrike: QGradient = ...
        NightCall: QGradient = ...
        SupremeSky: QGradient = ...
        LightBlue: QGradient = ...
        MindCrawl: QGradient = ...
        LilyMeadow: QGradient = ...
        SugarLollipop: QGradient = ...
        SweetDessert: QGradient = ...
        MagicRay: QGradient = ...
        TeenParty: QGradient = ...
        FrozenHeat: QGradient = ...
        GagarinView: QGradient = ...
        FabledSunset: QGradient = ...
        PerfectBlue: QGradient = ...
        NumPresets: QGradient = ...

    class Spread(enum.Enum):
        PadSpread: QGradient = ...
        ReflectSpread: QGradient = ...
        RepeatSpread: QGradient = ...

    class Type(enum.Enum):
        LinearGradient: QGradient = ...
        RadialGradient: QGradient = ...
        ConicalGradient: QGradient = ...
        NoGradient: QGradient = ...

    class CoordinateMode(enum.Enum):
        LogicalMode: QGradient = ...
        StretchToDeviceMode: QGradient = ...
        ObjectBoundingMode: QGradient = ...
        ObjectMode: QGradient = ...

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qgradient.html#QGradient-1

        **[since 5.12] QGradient::QGradient(QGradient::Preset preset )**

        Constructs a gradient based on a predefined **preset**.

        The coordinate mode of the resulting gradient is
        **QGradient::ObjectMode** , allowing the preset to be applied to
        arbitrary object sizes.

        This function was introduced in Qt 5.12.
        """
        ...

    @typing.overload
    def __init__(self, a0: "QGradient.Preset") -> None:
        """
        https://doc.qt.io/qt-6/qgradient.html#QGradient-1

        **[since 5.12] QGradient::QGradient(QGradient::Preset preset )**

        Constructs a gradient based on a predefined **preset**.

        The coordinate mode of the resulting gradient is
        **QGradient::ObjectMode** , allowing the preset to be applied to
        arbitrary object sizes.

        This function was introduced in Qt 5.12.
        """
        ...

    @typing.overload
    def __init__(self, a0: "QGradient") -> None:
        """
        https://doc.qt.io/qt-6/qgradient.html#QGradient-1

        **[since 5.12] QGradient::QGradient(QGradient::Preset preset )**

        Constructs a gradient based on a predefined **preset**.

        The coordinate mode of the resulting gradient is
        **QGradient::ObjectMode** , allowing the preset to be applied to
        arbitrary object sizes.

        This function was introduced in Qt 5.12.
        """
        ...

    def setCoordinateMode(self, mode: "QGradient.CoordinateMode") -> None:
        """
        https://doc.qt.io/qt-6/qgradient.html#setCoordinateMode

        **void QGradient::setCoordinateMode(QGradient::CoordinateMode mode )**

        Sets the coordinate mode of this gradient to **mode**. The default mode
        is **LogicalMode** .

        **See also** **coordinateMode** ().
        """
        ...

    def coordinateMode(self) -> "QGradient.CoordinateMode":
        """
        https://doc.qt.io/qt-6/qgradient.html#coordinateMode

        **QGradient::CoordinateMode QGradient::coordinateMode() const**

        Returns the coordinate mode of this gradient. The default mode is
        **LogicalMode** .

        **See also** **setCoordinateMode** ().
        """
        ...

    def setSpread(self, aspread: "QGradient.Spread") -> None:
        """
        https://doc.qt.io/qt-6/qgradient.html#setSpread

        **void QGradient::setSpread(QGradient::Spread method )**

        Specifies the spread **method** that should be used for this gradient.

        Note that this function only has effect for linear and radial gradients.

        **See also** **spread** ().
        """
        ...

    def stops(self) -> typing.List[typing.Tuple[float, QColor]]:
        """
        https://doc.qt.io/qt-6/qgradient.html#stops

        **QGradientStops QGradient::stops() const**

        Returns the stop points for this gradient.

        If no stop points have been specified, a gradient of black at 0 to white
        at 1 is used.

        **See also** **setStops** () and **setColorAt** ().
        """
        ...

    def setStops(
        self,
        stops: typing.Iterable[
            typing.Tuple[
                float, typing.Union[QColor, QtCore.Qt.GlobalColor, int, "QGradient"]
            ]
        ],
    ) -> None:
        """
        https://doc.qt.io/qt-6/qgradient.html#setStops

        **void QGradient::setStops(const QGradientStops & stopPoints )**

        Replaces the current set of stop points with the given **stopPoints**.
        The positions of the points must be in the range 0 to 1, and must be
        sorted with the lowest point first.

        **See also** **setColorAt** () and **stops** ().
        """
        ...

    def setColorAt(
        self,
        pos: float,
        color: typing.Union[QColor, QtCore.Qt.GlobalColor, int, "QGradient"],
    ) -> None:
        """
        https://doc.qt.io/qt-6/qgradient.html#setColorAt

        **void QGradient::setColorAt(qreal position , const QColor & color )**

        Creates a stop point at the given **position** with the given **color**.
        The given **position** must be in the range 0 to 1.

        **See also** **setStops** () and **stops** ().
        """
        ...

    def spread(self) -> "QGradient.Spread":
        """
        https://doc.qt.io/qt-6/qgradient.html#spread

        **QGradient::Spread QGradient::spread() const**

        Returns the spread method use by this gradient. The default is
        **PadSpread** .

        **See also** **setSpread** ().
        """
        ...

    def type(self) -> "QGradient.Type":
        """
        https://doc.qt.io/qt-6/qgradient.html#type

        **QGradient::Type QGradient::type() const**

        Returns the type of gradient.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import PyQt6.sip
from PyQt6.QtWebSockets import *
import enum


class QWebSocketProtocol(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qwebsocketprotocol.html

    **Detailed Description**
    """

    class CloseCode(enum.Enum):
        CloseCodeNormal: QWebSocketProtocol = ...
        CloseCodeGoingAway: QWebSocketProtocol = ...
        CloseCodeProtocolError: QWebSocketProtocol = ...
        CloseCodeDatatypeNotSupported: QWebSocketProtocol = ...
        CloseCodeReserved1004: QWebSocketProtocol = ...
        CloseCodeMissingStatusCode: QWebSocketProtocol = ...
        CloseCodeAbnormalDisconnection: QWebSocketProtocol = ...
        CloseCodeWrongDatatype: QWebSocketProtocol = ...
        CloseCodePolicyViolated: QWebSocketProtocol = ...
        CloseCodeTooMuchData: QWebSocketProtocol = ...
        CloseCodeMissingExtension: QWebSocketProtocol = ...
        CloseCodeBadOperation: QWebSocketProtocol = ...
        CloseCodeTlsHandshakeFailed: QWebSocketProtocol = ...

    class Version(enum.Enum):
        VersionUnknown: QWebSocketProtocol = ...
        Version0: QWebSocketProtocol = ...
        Version4: QWebSocketProtocol = ...
        Version5: QWebSocketProtocol = ...
        Version6: QWebSocketProtocol = ...
        Version7: QWebSocketProtocol = ...
        Version8: QWebSocketProtocol = ...
        Version13: QWebSocketProtocol = ...
        VersionLatest: QWebSocketProtocol = ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6 import QtCore
from PyQt6.QtSql import *
import enum


class QSqlTableModel(QSqlQueryModel):
    """
    https://doc.qt.io/qt-6/qsqltablemodel.html

    **Detailed Description**

    QSqlTableModel is a high-level interface for reading and writing database
    records from a single table. It is built on top of the lower-level
    **QSqlQuery**  and can be used to provide data to view classes such as
    **QTableView** . For example:

    **QSqlTableModel**  *model = new **QSqlTableModel** ;
    model->setTable("employee");
    model->setEditStrategy(**QSqlTableModel** ::OnManualSubmit);
    model->select();
            model->setHeaderData(0, Qt::Horizontal,
    tr("Name"));
            model->setHeaderData(1, Qt::Horizontal, tr("Salary"));
    **QTableView**  *view = new **QTableView** ;
            view->setModel(model);
    view->hideColumn(0); // don't show the ID
            view->show();

    We set the SQL table's name and the edit strategy, then we set up the labels
    displayed in the view header. The edit strategy dictates when the changes
    done by the user in the view are actually applied to the database. The
    possible values are **OnFieldChange** , **OnRowChange** , and
    **OnManualSubmit** .

    QSqlTableModel can also be used to access a database programmatically,
    without binding it to a view:

    **QSqlTableModel**  model;
            model.setTable("employee");
    model.select();
            int salary =
    model.record(4).value("salary").toInt();

    The code snippet above extracts the `salary` field from record 4 in the
    result set of the query `SELECT * from employee`.

    It is possible to set filters using **setFilter** (), or modify the sort
    order using **setSort** (). At the end, you must call **select** () to
    populate the model with data.

    The **tablemodel**  example illustrates how to use QSqlTableModel as the
    data source for a **QTableView** .

    QSqlTableModel provides no direct support for foreign keys. Use the
    **QSqlRelationalTableModel**  and **QSqlRelationalDelegate**  if you want to
    resolve foreign keys.

    **See also** **QSqlRelationalTableModel** , **QSqlQuery** , **Model/View
    Programming** , **Table Model Example** , and **Cached Table Example** .
    """

    class EditStrategy(enum.Enum):
        OnFieldChange: QSqlTableModel = ...
        OnRowChange: QSqlTableModel = ...
        OnManualSubmit: QSqlTableModel = ...

    def __init__(
        self, parent: typing.Optional[QtCore.QObject] = ..., db: QSqlDatabase = ...
    ) -> None:
        """
        https://doc.qt.io/qt-6/qsqltablemodel.html#QSqlTableModel

        **QSqlTableModel::QSqlTableModel(QObject * parent = nullptr, const
        QSqlDatabase & db = QSqlDatabase())**

        Creates an empty QSqlTableModel and sets the parent to **parent** and
        the database connection to **db**. If **db** is not valid, the default
        database connection will be used.

        The default edit strategy is **OnRowChange** .
        """
        ...

    def clearItemData(self, index: QtCore.QModelIndex) -> bool:
        """
        https://doc.qt.io/qt-6/qsqltablemodel.html#clearItemData

        **[override virtual] bool QSqlTableModel::clearItemData(const
        QModelIndex & index )**

        Reimplements: **QAbstractItemModel::clearItemData** (const QModelIndex
        &index).
        """
        ...

    @typing.overload
    def record(self) -> QSqlRecord:
        """
        https://doc.qt.io/qt-6/qsqltablemodel.html#record

        **QSqlRecord QSqlTableModel::record() const**

        This is an overloaded function.

        It returns an empty record, having only the field names. This function
        can be used to retrieve the field names of a record.

        **See also** **setRecord** () and **QSqlRecord::isEmpty** ().
        """
        ...

    @typing.overload
    def record(self, row: int) -> QSqlRecord:
        """
        https://doc.qt.io/qt-6/qsqltablemodel.html#record-1

        **[since 5.0] QSqlRecord QSqlTableModel::record(int row ) const**

        Returns the record at **row** in the model.

        If **row** is the index of a valid row, the record will be populated
        with values from that row.

        If the model is not initialized, an empty record will be returned.

        This function was introduced in Qt 5.0.

        **See also** **QSqlRecord::isEmpty** ().
        """
        ...

    def selectRow(self, row: int) -> bool:
        """
        https://doc.qt.io/qt-6/qsqltablemodel.html#selectRow

        **[virtual slot, since 5.0] bool QSqlTableModel::selectRow(int row )**

        Refreshes **row** in the model with values from the database table row
        matching on primary key values. Without a primary key, all column values
        must match. If no matching row is found, the model will show an empty
        row.

        Returns `true` if successful; otherwise returns `false`.

        This function was introduced in Qt 5.0.

        **See also** **select** ().
        """
        ...

    def primaryValues(self, row: int) -> QSqlRecord:
        """
        https://doc.qt.io/qt-6/qsqltablemodel.html#primaryValues

        **[protected, since 5.1] QSqlRecord QSqlTableModel::primaryValues(int
        row ) const**

        Returns a record containing the fields represented in the primary key
        set to the values at **row**. If no primary key is defined, the returned
        record will contain all fields.

        This function was introduced in Qt 5.1.

        **See also** **primaryKey** ().
        """
        ...

    def indexInQuery(self, item: QtCore.QModelIndex) -> QtCore.QModelIndex:
        """
        https://doc.qt.io/qt-6/qsqltablemodel.html#indexInQuery

        **[override virtual protected] QModelIndex
        QSqlTableModel::indexInQuery(const QModelIndex & item ) const**

        Reimplements: **QSqlQueryModel::indexInQuery(const QModelIndex &item)
        const** .

        Returns the index of the value in the database result set for the given
        **item** in the model.

        The return value is identical to **item** if no columns or rows have
        been inserted, removed, or moved around.

        Returns an invalid model index if **item** is out of bounds or if
        **item** does not point to a value in the result set.

        **See also** **QSqlQueryModel::indexInQuery** ().
        """
        ...

    def setQuery(self, query: QSqlQuery) -> None:
        """
        https://doc.qt.io/qt-6/qsqltablemodel.html#setQuery

        **[protected] void QSqlTableModel::setQuery(const QSqlQuery & query )**

        This function simply calls **QSqlQueryModel::setQuery** ( **query** ).
        You should normally not call it on a **QSqlTableModel** . Instead, use
        **setTable** (), **setSort** (), **setFilter** (), etc., to set up the
        query.

        **See also** **selectStatement** ().
        """
        ...

    def setPrimaryKey(self, key: QSqlIndex) -> None:
        """
        https://doc.qt.io/qt-6/qsqltablemodel.html#setPrimaryKey

        **[protected] void QSqlTableModel::setPrimaryKey(const QSqlIndex & key
        )**

        Protected method that allows subclasses to set the primary key to
        **key**.

        Normally, the primary index is set automatically whenever you call
        **setTable** ().

        **See also** **primaryKey** () and **QSqlDatabase::primaryIndex** ().
        """
        ...

    def selectStatement(self) -> str:
        """
        https://doc.qt.io/qt-6/qsqltablemodel.html#selectStatement

        **[virtual protected] QString QSqlTableModel::selectStatement() const**

        Returns the SQL `SELECT` statement used internally to populate the
        model. The statement includes the filter and the `ORDER BY` clause.

        **See also** **filter** () and **orderByClause** ().
        """
        ...

    def orderByClause(self) -> str:
        """
        https://doc.qt.io/qt-6/qsqltablemodel.html#orderByClause

        **[virtual protected] QString QSqlTableModel::orderByClause() const**

        Returns an SQL `ORDER BY` clause based on the currently set sort order.

        **See also** **setSort** () and **selectStatement** ().
        """
        ...

    def deleteRowFromTable(self, row: int) -> bool:
        """
        https://doc.qt.io/qt-6/qsqltablemodel.html#deleteRowFromTable

        **[virtual protected] bool QSqlTableModel::deleteRowFromTable(int row
        )**

        Deletes the given **row** from the currently active database table.

        This is a low-level method that operates directly on the database and
        should not be called directly. Use **removeRow** () or **removeRows** ()
        to delete values. The model will decide depending on its edit strategy
        when to modify the database.

        Returns `true` if the row was deleted; otherwise returns `false`.

        **See also** **removeRow** () and **removeRows** ().
        """
        ...

    def insertRowIntoTable(self, values: QSqlRecord) -> bool:
        """
        https://doc.qt.io/qt-6/qsqltablemodel.html#insertRowIntoTable

        **[virtual protected] bool QSqlTableModel::insertRowIntoTable(const
        QSqlRecord & values )**

        Inserts the values **values** into the currently active database table.

        This is a low-level method that operates directly on the database and
        should not be called directly. Use **insertRow** () and **setData** ()
        to insert values. The model will decide depending on its edit strategy
        when to modify the database.

        Returns `true` if the values could be inserted, otherwise false. Error
        information can be retrieved with **lastError** ().

        **See also** **lastError** (), **insertRow** (), and **insertRows** ().
        """
        ...

    def updateRowInTable(self, row: int, values: QSqlRecord) -> bool:
        """
        https://doc.qt.io/qt-6/qsqltablemodel.html#updateRowInTable

        **[virtual protected] bool QSqlTableModel::updateRowInTable(int row ,
        const QSqlRecord & values )**

        Updates the given **row** in the currently active database table with
        the specified **values**. Returns `true` if successful; otherwise
        returns `false`.

        This is a low-level method that operates directly on the database and
        should not be called directly. Use **setData** () to update values. The
        model will decide depending on its edit strategy when to modify the
        database.

        Note that only values that have the generated-flag set are updated. The
        generated-flag can be set with **QSqlRecord::setGenerated** () and
        tested with **QSqlRecord::isGenerated** ().

        **See also** **QSqlRecord::isGenerated** () and **setData** ().
        """
        ...

    def revertAll(self) -> None:
        """
        https://doc.qt.io/qt-6/qsqltablemodel.html#revertAll

        **[slot] void QSqlTableModel::revertAll()**

        Reverts all pending changes.

        **See also** **revert** (), **revertRow** (), and **submitAll** ().
        """
        ...

    def submitAll(self) -> bool:
        """
        https://doc.qt.io/qt-6/qsqltablemodel.html#submitAll

        **[slot] bool QSqlTableModel::submitAll()**

        Submits all pending changes and returns `true` on success. Returns
        `false` on error, detailed error information can be obtained with
        **lastError** ().

        In **OnManualSubmit** , on success the model will be repopulated. Any
        views presenting it will lose their selections.

        Note: In **OnManualSubmit**  mode, already submitted changes won't be
        cleared from the cache when submitAll() fails. This allows transactions
        to be rolled back and resubmitted without losing data.

        **See also** **revertAll** () and **lastError** ().
        """
        ...

    def revert(self) -> None:
        """
        https://doc.qt.io/qt-6/qsqltablemodel.html#revert

        **[override virtual slot] void QSqlTableModel::revert()**

        Reimplements: **QAbstractItemModel::revert** ().

        This reimplemented slot is called by the item delegates when the user
        canceled editing the current row.

        Reverts the changes if the model's strategy is set to **OnRowChange**
        or **OnFieldChange** . Does nothing for the **OnManualSubmit**
        strategy.

        Use **revertAll** () to revert all pending changes for the
        **OnManualSubmit**  strategy or **revertRow** () to revert a specific
        row.

        **See also** **submit** (), **submitAll** (), **revertRow** (), and
        **revertAll** ().
        """
        ...

    def submit(self) -> bool:
        """
        https://doc.qt.io/qt-6/qsqltablemodel.html#submit

        **[override virtual slot] bool QSqlTableModel::submit()**

        Reimplements: **QAbstractItemModel::submit** ().

        This reimplemented slot is called by the item delegates when the user
        stopped editing the current row.

        Submits the currently edited row if the model's strategy is set to
        **OnRowChange**  or **OnFieldChange** . Does nothing for the
        **OnManualSubmit**  strategy.

        Use **submitAll** () to submit all pending changes for the
        **OnManualSubmit**  strategy.

        Returns `true` on success; otherwise returns `false`. Use **lastError**
        () to query detailed error information.

        Does not automatically repopulate the model. Submitted rows are
        refreshed from the database on success.

        **See also** **revert** (), **revertRow** (), **submitAll** (),
        **revertAll** (), and **lastError** ().
        """
        ...

    def revertRow(self, row: int) -> None:
        """
        https://doc.qt.io/qt-6/qsqltablemodel.html#revertRow

        **[virtual] void QSqlTableModel::revertRow(int row )**

        Reverts all changes for the specified **row**.

        **See also** **revert** (), **revertAll** (), **submit** (), and
        **submitAll** ().
        """
        ...

    def setRecord(self, row: int, record: QSqlRecord) -> bool:
        """
        https://doc.qt.io/qt-6/qsqltablemodel.html#setRecord

        **bool QSqlTableModel::setRecord(int row , const QSqlRecord & values )**

        Applies **values** to the **row** in the model. The source and target
        fields are mapped by field name, not by position in the record.

        Note that the generated flags in **values** are preserved to determine
        whether the corresponding fields are used when changes are submitted to
        the database. By default, it is set to `true` for all fields in a
        **QSqlRecord** . You must set the flag to `false` using **setGenerated**
        (false) for any value in **values** , to save changes back to the
        database.

        For edit strategies **OnFieldChange**  and **OnRowChange** , a row may
        receive a change only if no other row has a cached change. Changes are
        submitted immediately. Submitted changes are not reverted upon failure.

        Returns `true` if all the values could be set; otherwise returns false.

        **See also** **record** () and **editStrategy** ().
        """
        ...

    def insertRecord(self, row: int, record: QSqlRecord) -> bool:
        """
        https://doc.qt.io/qt-6/qsqltablemodel.html#insertRecord

        **bool QSqlTableModel::insertRecord(int row , const QSqlRecord & record
        )**

        Inserts the **record** at position **row**. If **row** is negative, the
        record will be appended to the end. Calls **insertRows** () and
        **setRecord** () internally.

        Returns `true` if the record could be inserted, otherwise false.

        Changes are submitted immediately for **OnFieldChange**  and
        **OnRowChange** . Failure does not leave a new row in the model.

        **See also** **insertRows** (), **removeRows** (), and **setRecord** ().
        """
        ...

    def insertRows(
        self, row: int, count: int, parent: QtCore.QModelIndex = ...
    ) -> bool:
        """
        https://doc.qt.io/qt-6/qsqltablemodel.html#insertRows

        **[override virtual] bool QSqlTableModel::insertRows(int row , int count
        , const QModelIndex & parent = QModelIndex())**

        Reimplements: **QAbstractItemModel::insertRows** (int row, int count,
        const QModelIndex &parent).

        Inserts **count** empty rows at position **row**. Note that **parent**
        must be invalid, since this model does not support parent-child
        relations.

        For edit strategies **OnFieldChange**  and **OnRowChange** , only one
        row may be inserted at a time and the model may not contain other cached
        changes.

        The **primeInsert** () signal will be emitted for each new row. Connect
        to it if you want to initialize the new row with default values.

        Does not submit rows, regardless of edit strategy.

        Returns `false` if the parameters are out of bounds or the row cannot be
        inserted; otherwise returns `true`.

        **See also** **primeInsert** () and **insertRecord** ().
        """
        ...

    def removeRows(
        self, row: int, count: int, parent: QtCore.QModelIndex = ...
    ) -> bool:
        """
        https://doc.qt.io/qt-6/qsqltablemodel.html#removeRows

        **[override virtual] bool QSqlTableModel::removeRows(int row , int count
        , const QModelIndex & parent = QModelIndex())**

        Reimplements: **QAbstractItemModel::removeRows** (int row, int count,
        const QModelIndex &parent).

        Removes **count** rows starting at **row**. Since this model does not
        support hierarchical structures, **parent** must be an invalid model
        index.

        When the edit strategy is **OnManualSubmit** , deletion of rows from the
        database is delayed until **submitAll** () is called.

        For **OnFieldChange**  and **OnRowChange** , only one row may be deleted
        at a time and only if no other row has a cached change. Deletions are
        submitted immediately to the database. The model retains a blank row for
        successfully deleted row until refreshed with **select** ().

        After failed deletion, the operation is not reverted in the model. The
        application may resubmit or revert.

        Inserted but not yet successfully submitted rows in the range to be
        removed are immediately removed from the model.

        Before a row is deleted from the database, the **beforeDelete** ()
        signal is emitted.

        If row < 0 or row + count > **rowCount** (), no action is taken and
        false is returned. Returns `true` if all rows could be removed;
        otherwise returns `false`. Detailed database error information can be
        retrieved using **lastError** ().

        **See also** **removeColumns** () and **insertRows** ().
        """
        ...

    def removeColumns(
        self, column: int, count: int, parent: QtCore.QModelIndex = ...
    ) -> bool:
        """
        https://doc.qt.io/qt-6/qsqltablemodel.html#removeColumns

        **[override virtual] bool QSqlTableModel::removeColumns(int column , int
        count , const QModelIndex & parent = QModelIndex())**

        Reimplements: **QSqlQueryModel::removeColumns** (int column, int count,
        const QModelIndex &parent).

        Removes **count** columns from the **parent** model, starting at index
        **column**.

        Returns if the columns were successfully removed; otherwise returns
        `false`.

        **See also** **removeRows** ().
        """
        ...

    def rowCount(self, parent: QtCore.QModelIndex = ...) -> int:
        """
        https://doc.qt.io/qt-6/qsqltablemodel.html#rowCount

        **[override virtual] int QSqlTableModel::rowCount(const QModelIndex &
        parent = QModelIndex()) const**

        Reimplements: **QSqlQueryModel::rowCount(const QModelIndex &parent)
        const** .
        """
        ...

    def setFilter(self, filter: str) -> None:
        """
        https://doc.qt.io/qt-6/qsqltablemodel.html#setFilter

        **[virtual] void QSqlTableModel::setFilter(const QString & filter )**

        Sets the current filter to **filter**.

        The filter is a SQL `WHERE` clause without the keyword `WHERE` (for
        example, `name='Josephine')`.

        If the model is already populated with data from a database, the model
        re-selects it with the new filter. Otherwise, the filter will be applied
        the next time **select** () is called.

        **See also** **filter** (), **select** (), **selectStatement** (), and
        **orderByClause** ().
        """
        ...

    def filter(self) -> str:
        """
        https://doc.qt.io/qt-6/qsqltablemodel.html#filter

        **QString QSqlTableModel::filter() const**

        Returns the currently set filter.

        **See also** **setFilter** () and **select** ().
        """
        ...

    def setSort(self, column: int, order: QtCore.Qt.SortOrder) -> None:
        """
        https://doc.qt.io/qt-6/qsqltablemodel.html#setSort

        **[virtual] void QSqlTableModel::setSort(int column , Qt::SortOrder
        order )**

        Sets the sort order for **column** to **order**. This does not affect
        the current data, to refresh the data using the new sort order, call
        **select** ().

        **See also** **sort** (), **select** (), and **orderByClause** ().
        """
        ...

    def sort(self, column: int, order: QtCore.Qt.SortOrder) -> None:
        """
        https://doc.qt.io/qt-6/qsqltablemodel.html#sort

        **[override virtual] void QSqlTableModel::sort(int column ,
        Qt::SortOrder order )**

        Reimplements: **QAbstractItemModel::sort** (int column, Qt::SortOrder
        order).

        Sorts the data by **column** with the sort order **order**. This will
        immediately select data, use **setSort** () to set a sort order without
        populating the model with data.

        **See also** **setSort** (), **select** (), and **orderByClause** ().
        """
        ...

    def fieldIndex(self, fieldName: str) -> int:
        """
        https://doc.qt.io/qt-6/qsqltablemodel.html#fieldIndex

        **int QSqlTableModel::fieldIndex(const QString & fieldName ) const**

        Returns the index of the field **fieldName** , or -1 if no corresponding
        field exists in the model.
        """
        ...

    def database(self) -> QSqlDatabase:
        """
        https://doc.qt.io/qt-6/qsqltablemodel.html#database

        **QSqlDatabase QSqlTableModel::database() const**

        Returns the model's database connection.
        """
        ...

    def primaryKey(self) -> QSqlIndex:
        """
        https://doc.qt.io/qt-6/qsqltablemodel.html#primaryKey

        **QSqlIndex QSqlTableModel::primaryKey() const**

        Returns the primary key for the current table, or an empty **QSqlIndex**
        if the table is not set or has no primary key.

        **See also** **setTable** (), **setPrimaryKey** (), and
        **QSqlDatabase::primaryIndex** ().
        """
        ...

    def editStrategy(self) -> "QSqlTableModel.EditStrategy":
        """
        https://doc.qt.io/qt-6/qsqltablemodel.html#editStrategy

        **QSqlTableModel::EditStrategy QSqlTableModel::editStrategy() const**

        Returns the current edit strategy.

        **See also** **setEditStrategy** ().
        """
        ...

    def setEditStrategy(self, strategy: "QSqlTableModel.EditStrategy") -> None:
        """
        https://doc.qt.io/qt-6/qsqltablemodel.html#setEditStrategy

        **[virtual] void
        QSqlTableModel::setEditStrategy(QSqlTableModel::EditStrategy strategy
        )**

        Sets the strategy for editing values in the database to **strategy**.

        This will revert any pending changes.

        **See also** **editStrategy** () and **revertAll** ().
        """
        ...

    def clear(self) -> None:
        """
        https://doc.qt.io/qt-6/qsqltablemodel.html#clear

        **[override virtual] void QSqlTableModel::clear()**

        Reimplements: **QSqlQueryModel::clear** ().
        """
        ...

    @typing.overload
    def isDirty(self, index: QtCore.QModelIndex) -> bool:
        """
        https://doc.qt.io/qt-6/qsqltablemodel.html#isDirty

        **bool QSqlTableModel::isDirty(const QModelIndex & index ) const**

        Returns `true` if the value at the index **index** is dirty, otherwise
        false. Dirty values are values that were modified in the model but not
        yet written into the database.

        If **index** is invalid or points to a non-existing row, false is
        returned.
        """
        ...

    @typing.overload
    def isDirty(self) -> bool:
        """
        https://doc.qt.io/qt-6/qsqltablemodel.html#isDirty-1

        **[since 5.0] bool QSqlTableModel::isDirty() const**

        This is an overloaded function.

        Returns `true` if the model contains modified values that have not been
        committed to the database, otherwise false.

        This function was introduced in Qt 5.0.
        """
        ...

    def headerData(
        self, section: int, orientation: QtCore.Qt.Orientation, role: int = ...
    ) -> typing.Any:
        """
        https://doc.qt.io/qt-6/qsqltablemodel.html#headerData

        **[override virtual] QVariant QSqlTableModel::headerData(int section ,
        Qt::Orientation orientation , int role = Qt::DisplayRole) const**

        Reimplements: **QSqlQueryModel::headerData(int section, Qt::Orientation
        orientation, int role) const** .
        """
        ...

    def setData(
        self, index: QtCore.QModelIndex, value: typing.Any, role: int = ...
    ) -> bool:
        """
        https://doc.qt.io/qt-6/qsqltablemodel.html#setData

        **[override virtual] bool QSqlTableModel::setData(const QModelIndex &
        index , const QVariant & value , int role = Qt::EditRole)**

        Reimplements: **QAbstractItemModel::setData** (const QModelIndex &index,
        const QVariant &value, int role).

        Sets the data for the item **index** for the role **role** to **value**.

        For edit strategy **OnFieldChange** , an index may receive a change only
        if no other index has a cached change. Changes are submitted
        immediately. However, rows that have not yet been inserted in the
        database may be freely changed and are not submitted automatically.
        Submitted changes are not reverted upon failure.

        For **OnRowChange** , an index may receive a change only if no other row
        has a cached change. Changes are not submitted automatically.

        Returns `true` if **value** is equal to the current value. However, the
        value will not be submitted to the database.

        Returns `true` if the value could be set or false on error, for example
        if **index** is out of bounds.

        Returns `false` if the role is not **Qt::EditRole** . To set data for
        roles other than EditRole, either use a custom proxy model or subclass
        **QSqlTableModel** .

        **See also** **editStrategy** (), **data** (), **submit** (),
        **submitAll** (), and **revertRow** ().
        """
        ...

    def data(self, idx: QtCore.QModelIndex, role: int = ...) -> typing.Any:
        """
        https://doc.qt.io/qt-6/qsqltablemodel.html#data

        **[override virtual] QVariant QSqlTableModel::data(const QModelIndex &
        index , int role = Qt::DisplayRole) const**

        Reimplements: **QSqlQueryModel::data(const QModelIndex &item, int role)
        const** .

        **See also** **setData** ().
        """
        ...

    def flags(self, index: QtCore.QModelIndex) -> QtCore.Qt.ItemFlag:
        """
        https://doc.qt.io/qt-6/qsqltablemodel.html#flags

        **[override virtual] Qt::ItemFlags QSqlTableModel::flags(const
        QModelIndex & index ) const**

        Reimplements: **QAbstractTableModel::flags(const QModelIndex &index)
        const** .
        """
        ...

    def tableName(self) -> str:
        """
        https://doc.qt.io/qt-6/qsqltablemodel.html#tableName

        **QString QSqlTableModel::tableName() const**

        Returns the name of the currently selected table.
        """
        ...

    def setTable(self, tableName: str) -> None:
        """
        https://doc.qt.io/qt-6/qsqltablemodel.html#setTable

        **[virtual] void QSqlTableModel::setTable(const QString & tableName )**

        Sets the database table on which the model operates to **tableName**.
        Does not select data from the table, but fetches its field information.

        To populate the model with the table's data, call **select** ().

        Error information can be retrieved with **lastError** ().

        **See also** **select** (), **setFilter** (), and **lastError** ().
        """
        ...

    def select(self) -> bool:
        """
        https://doc.qt.io/qt-6/qsqltablemodel.html#select

        **[virtual slot] bool QSqlTableModel::select()**

        Populates the model with data from the table that was set via
        **setTable** (), using the specified filter and sort condition, and
        returns `true` if successful; otherwise returns `false`.

        **Note:** Calling select() will revert any unsubmitted changes and
        remove any inserted columns.

        **See also** **setTable** (), **setFilter** (), and **selectStatement**
        ().
        """
        ...

    @property
    def beforeDelete(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qsqltablemodel.html#beforeDelete

        **[signal] void QSqlTableModel::beforeDelete(int row )**

        This signal is emitted by **deleteRowFromTable** () before the **row**
        is deleted from the currently active database table.
        """
        ...

    @property
    def beforeInsert(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qsqltablemodel.html#beforeInsert

        **[signal] void QSqlTableModel::beforeInsert(QSqlRecord & record )**

        This signal is emitted by **insertRowIntoTable** () before a new row is
        inserted into the currently active database table. The values that are
        about to be inserted are stored in **record** and can be modified before
        they will be inserted.
        """
        ...

    @property
    def beforeUpdate(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qsqltablemodel.html#beforeUpdate

        **[signal] void QSqlTableModel::beforeUpdate(int row , QSqlRecord &
        record )**

        This signal is emitted by **updateRowInTable** () before the **row** is
        updated in the currently active database table with the values from
        **record**.

        Note that only values that are marked as generated will be updated. The
        generated flag can be set with **QSqlRecord::setGenerated** () and
        checked with **QSqlRecord::isGenerated** ().

        **See also** **QSqlRecord::isGenerated** ().
        """
        ...

    @property
    def primeInsert(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qsqltablemodel.html#primeInsert

        **[signal] void QSqlTableModel::primeInsert(int row , QSqlRecord &
        record )**

        This signal is emitted by **insertRows** (), when an insertion is
        initiated in the given **row** of the currently active database table.
        The **record** parameter can be written to (since it is a reference),
        for example to populate some fields with default values and set the
        generated flags of the fields. Do not try to edit the record via other
        means such as **setData** () or **setRecord** () while handling this
        signal.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6.QtCore import *


class QMetaProperty(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qmetaproperty.html

    **Detailed Description**

    Property meta-data is obtained from an object's meta-object. See
    **QMetaObject::property** () and **QMetaObject::propertyCount** () for
    details.

    **Property Meta-Data**

    A property has a **name** () and a type(), as well as various attributes
    that specify its behavior: **isReadable** (), **isWritable** (),
    **isDesignable** (), **isScriptable** (), **revision** (), and **isStored**
    ().

    If the property is an enumeration, **isEnumType** () returns `true`; if the
    property is an enumeration that is also a flag (i.e. its values can be
    combined using the OR operator), **isEnumType** () and **isFlagType** ()
    both return true. The enumerator for these types is available from
    **enumerator** ().

    The property's values are set and retrieved with **read** (), **write** (),
    and **reset** (); they can also be changed through **QObject** 's set and
    get functions. See **QObject::setProperty** () and **QObject::property** ()
    for details.

    **Copying and Assignment**

    QMetaProperty objects can be copied by value. However, each copy will refer
    to the same underlying property meta-data.

    **See also** **QMetaObject** , **QMetaEnum** , **QMetaMethod** , and **Qt's
    Property System** .
    """

    @typing.overload
    def __init__(self) -> None:
        ...

    @typing.overload
    def __init__(self, a0: "QMetaProperty") -> None:
        ...

    def typeId(self) -> int:
        """
        https://doc.qt.io/qt-6/qmetaproperty.html#typeId

        **[since 6.0] int QMetaProperty::typeId() const**

        Returns the storage type of the property. This is the same as
        **metaType** ().id().

        This function was introduced in Qt 6.0.

        **See also** **QMetaType** , **typeName** (), and **metaType** ().
        """
        ...

    def isBindable(self) -> bool:
        """
        https://doc.qt.io/qt-6/qmetaproperty.html#isBindable

        **[since 6.0] bool QMetaProperty::isBindable() const**

        Returns `true` if the `Q_PROPERTY()` exposes binding functionality;
        otherwise returns false.

        This implies that you can create bindings that use this property as a
        dependency or install QPropertyObserver objects on this property. Unless
        the property is readonly, you can also set a binding on this property.

        This function was introduced in Qt 6.0.

        **See also** **QProperty** , **isWritable** (), and **bindable** ().
        """
        ...

    def metaType(self) -> "QMetaType":
        """
        https://doc.qt.io/qt-6/qmetaproperty.html#metaType

        **[since 6.0] QMetaType QMetaProperty::metaType() const**

        Returns this property's **QMetaType** .

        This function was introduced in Qt 6.0.

        **See also** **QMetaType** .
        """
        ...

    def isRequired(self) -> bool:
        """
        https://doc.qt.io/qt-6/qmetaproperty.html#isRequired

        **[since 5.15] bool QMetaProperty::isRequired() const**

        Returns `true` if the property is required; otherwise returns `false`.

        A property is final if the `Q_PROPERTY()`'s `REQUIRED` attribute is set.

        This function was introduced in Qt 5.15.
        """
        ...

    def relativePropertyIndex(self) -> int:
        """
        https://doc.qt.io/qt-6/qmetaproperty.html#relativePropertyIndex

        **[since 5.14] int QMetaProperty::relativePropertyIndex() const**

        Returns this property's index relative within the enclosing meta object.

        This function was introduced in Qt 5.14.
        """
        ...

    def isFinal(self) -> bool:
        """
        https://doc.qt.io/qt-6/qmetaproperty.html#isFinal

        **bool QMetaProperty::isFinal() const**

        Returns `true` if the property is final; otherwise returns `false`.

        A property is final if the `Q_PROPERTY()`'s `FINAL` attribute is set.
        """
        ...

    def isConstant(self) -> bool:
        """
        https://doc.qt.io/qt-6/qmetaproperty.html#isConstant

        **bool QMetaProperty::isConstant() const**

        Returns `true` if the property is constant; otherwise returns `false`.

        A property is constant if the `Q_PROPERTY()`'s `CONSTANT` attribute is
        set.
        """
        ...

    def propertyIndex(self) -> int:
        """
        https://doc.qt.io/qt-6/qmetaproperty.html#propertyIndex

        **int QMetaProperty::propertyIndex() const**

        Returns this property's index.
        """
        ...

    def notifySignalIndex(self) -> int:
        """
        https://doc.qt.io/qt-6/qmetaproperty.html#notifySignalIndex

        **int QMetaProperty::notifySignalIndex() const**

        Returns the index of the property change notifying signal if one was
        specified, otherwise returns -1.

        **See also** **hasNotifySignal** ().
        """
        ...

    def notifySignal(self) -> QMetaMethod:
        """
        https://doc.qt.io/qt-6/qmetaproperty.html#notifySignal

        **QMetaMethod QMetaProperty::notifySignal() const**

        Returns the **QMetaMethod**  instance of the property change notifying
        signal if one was specified, otherwise returns an invalid
        **QMetaMethod** .

        **See also** **hasNotifySignal** ().
        """
        ...

    def hasNotifySignal(self) -> bool:
        """
        https://doc.qt.io/qt-6/qmetaproperty.html#hasNotifySignal

        **bool QMetaProperty::hasNotifySignal() const**

        Returns `true` if this property has a corresponding change notify
        signal; otherwise returns `false`.

        **See also** **notifySignal** ().
        """
        ...

    def userType(self) -> int:
        """
        https://doc.qt.io/qt-6/qmetaproperty.html#userType

        **int QMetaProperty::userType() const**

        Returns this property's user type. The return value is one of the values
        that are registered with **QMetaType** .

        This is equivalent to **metaType** ().id()

        **See also** **type** (), **QMetaType** , **typeName** (), and
        **metaType** ().
        """
        ...

    def isUser(self) -> bool:
        """
        https://doc.qt.io/qt-6/qmetaproperty.html#isUser

        **bool QMetaProperty::isUser() const**

        Returns `false` if the `Q_PROPERTY()`'s `USER` attribute is false.
        Otherwise it returns true, indicating the property is designated as the
        `USER` property, i.e., the one that the user can edit or that is
        significant in some other way.

        **See also** **QMetaObject::userProperty** (), **isDesignable** (), and
        **isScriptable** ().
        """
        ...

    def isResettable(self) -> bool:
        """
        https://doc.qt.io/qt-6/qmetaproperty.html#isResettable

        **bool QMetaProperty::isResettable() const**

        Returns `true` if this property can be reset to a default value;
        otherwise returns `false`.

        **See also** **reset** ().
        """
        ...

    def isValid(self) -> bool:
        """
        https://doc.qt.io/qt-6/qmetaproperty.html#isValid

        **bool QMetaProperty::isValid() const**

        Returns `true` if this property is valid (readable); otherwise returns
        `false`.

        **See also** **isReadable** ().
        """
        ...

    def hasStdCppSet(self) -> bool:
        ...

    def reset(self, obj: QObject) -> bool:
        """
        https://doc.qt.io/qt-6/qmetaproperty.html#reset

        **bool QMetaProperty::reset(QObject * object ) const**

        Resets the property for the given **object** with a reset method.
        Returns `true` if the reset worked; otherwise returns `false`.

        Reset methods are optional; only a few properties support them.

        **See also** **read** () and **write** ().
        """
        ...

    def write(self, obj: QObject, value: typing.Any) -> bool:
        """
        https://doc.qt.io/qt-6/qmetaproperty.html#write

        **bool QMetaProperty::write(QObject * object , const QVariant & value )
        const**

        Writes **value** as the property's value to the given **object**.
        Returns true if the write succeeded; otherwise returns `false`.

        If **value** is not of the same type type as the property, a conversion
        is attempted. An empty QVariant() is equivalent to a call to **reset**
        () if this property is resettable, or setting a default-constructed
        object otherwise.

        **See also** **read** (), **reset** (), and **isWritable** ().
        """
        ...

    def read(self, obj: QObject) -> typing.Any:
        """
        https://doc.qt.io/qt-6/qmetaproperty.html#read

        **QVariant QMetaProperty::read(const QObject * object ) const**

        Reads the property's value from the given **object**. Returns the value
        if it was able to read it; otherwise returns an invalid variant.

        **See also** **write** (), **reset** (), and **isReadable** ().
        """
        ...

    def enumerator(self) -> QMetaEnum:
        """
        https://doc.qt.io/qt-6/qmetaproperty.html#enumerator

        **QMetaEnum QMetaProperty::enumerator() const**

        Returns the enumerator if this property's type is an enumerator type;
        otherwise the returned value is undefined.

        **See also** **isEnumType** () and **isFlagType** ().
        """
        ...

    def isEnumType(self) -> bool:
        """
        https://doc.qt.io/qt-6/qmetaproperty.html#isEnumType

        **bool QMetaProperty::isEnumType() const**

        Returns `true` if the property's type is an enumeration value; otherwise
        returns `false`.

        **See also** **enumerator** () and **isFlagType** ().
        """
        ...

    def isFlagType(self) -> bool:
        """
        https://doc.qt.io/qt-6/qmetaproperty.html#isFlagType

        **bool QMetaProperty::isFlagType() const**

        Returns `true` if the property's type is an enumeration value that is
        used as a flag; otherwise returns `false`.

        Flags can be combined using the OR operator. A flag type is implicitly
        also an enum type.

        **See also** **isEnumType** (), **enumerator** (), and
        **QMetaEnum::isFlag** ().
        """
        ...

    def isStored(self) -> bool:
        """
        https://doc.qt.io/qt-6/qmetaproperty.html#isStored

        **bool QMetaProperty::isStored() const**

        Returns `true` if the property is stored; otherwise returns false.

        The function returns `false` if the `Q_PROPERTY()`'s `STORED` attribute
        is false; otherwise returns true.

        **See also** **isDesignable** () and **isScriptable** ().
        """
        ...

    def isScriptable(self) -> bool:
        """
        https://doc.qt.io/qt-6/qmetaproperty.html#isScriptable

        **bool QMetaProperty::isScriptable() const**

        Returns `false` if the `Q_PROPERTY()`'s `SCRIPTABLE` attribute is false;
        otherwise returns true.

        **See also** **isDesignable** () and **isStored** ().
        """
        ...

    def isDesignable(self) -> bool:
        """
        https://doc.qt.io/qt-6/qmetaproperty.html#isDesignable

        **bool QMetaProperty::isDesignable() const**

        Returns `false` if the `Q_PROPERTY()`'s `DESIGNABLE` attribute is false;
        otherwise returns `true`.

        **See also** **isScriptable** () and **isStored** ().
        """
        ...

    def isWritable(self) -> bool:
        """
        https://doc.qt.io/qt-6/qmetaproperty.html#isWritable

        **bool QMetaProperty::isWritable() const**

        Returns `true` if this property is writable; otherwise returns false.

        **See also** **isReadable** () and **write** ().
        """
        ...

    def isReadable(self) -> bool:
        """
        https://doc.qt.io/qt-6/qmetaproperty.html#isReadable

        **bool QMetaProperty::isReadable() const**

        Returns `true` if this property is readable; otherwise returns `false`.

        **See also** **isWritable** (), **read** (), and **isValid** ().
        """
        ...

    def typeName(self) -> str:
        """
        https://doc.qt.io/qt-6/qmetaproperty.html#typeName

        **const char *QMetaProperty::typeName() const**

        Returns the name of this property's type.

        **See also** **type** () and **name** ().
        """
        ...

    def name(self) -> str:
        """
        https://doc.qt.io/qt-6/qmetaproperty.html#name

        **const char *QMetaProperty::name() const**

        Returns this property's name.

        **See also** **type** () and **typeName** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6 import QtCore
from PyQt6.QtQml import *
import enum


class QQmlProperty(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qqmlproperty.html

    **Detailed Description**

    As QML uses Qt's meta-type system all of the existing **QMetaObject**
    classes can be used to introspect and interact with objects created by QML.
    However, some of the new features provided by QML - such as type safety and
    attached properties - are most easily used through the QQmlProperty class
    that simplifies some of their natural complexity.

    Unlike **QMetaProperty**  which represents a property on a class type,
    QQmlProperty encapsulates a property on a specific object instance. To read
    a property's value, programmers create a QQmlProperty instance and call the
    **read** () method. Likewise to write a property value the **write** ()
    method is used.

    For example, for the following QML code:

    // MyItem.qml
        import QtQuick 2.0

        **Text**  { text: "A bit of
    text" }

    The **Text**  object's properties could be accessed using QQmlProperty, like
    this:

    #include <QQmlProperty>
        #include <QGraphicsObject>

        ...
    **QQuickView**  view(**QUrl** ::fromLocalFile("MyItem.qml"));
    **QQmlProperty**  property(view.rootObject(), "font.pixelSize");
    **qWarning** () << "Current pixel size:" << property.read().toInt();
    property.write(24);
        **qWarning** () << "Pixel size should now be 24:" <<
    property.read().toInt();
    """

    class Type(enum.Enum):
        Invalid: QQmlProperty = ...
        Property: QQmlProperty = ...
        SignalProperty: QQmlProperty = ...

    class PropertyTypeCategory(enum.Enum):
        InvalidCategory: QQmlProperty = ...
        List: QQmlProperty = ...
        Object: QQmlProperty = ...
        Normal: QQmlProperty = ...

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qqmlproperty.html#QQmlProperty

        **QQmlProperty::QQmlProperty()**

        Create an invalid QQmlProperty.
        """
        ...

    @typing.overload
    def __init__(self, a0: QtCore.QObject) -> None:
        """
        https://doc.qt.io/qt-6/qqmlproperty.html#QQmlProperty-1

        **QQmlProperty::QQmlProperty(QObject * obj )**

        Creates a QQmlProperty for the default property of **obj**. If there is
        no default property, an invalid QQmlProperty will be created.
        """
        ...

    @typing.overload
    def __init__(self, a0: QtCore.QObject, a1: QQmlContext) -> None:
        """
        https://doc.qt.io/qt-6/qqmlproperty.html#QQmlProperty-2

        **QQmlProperty::QQmlProperty(QObject * obj , QQmlContext * ctxt )**

        Creates a QQmlProperty for the default property of **obj** using the
        **context**  **ctxt**. If there is no default property, an invalid
        QQmlProperty will be created.
        """
        ...

    @typing.overload
    def __init__(self, a0: QtCore.QObject, a1: QQmlEngine) -> None:
        """
        https://doc.qt.io/qt-6/qqmlproperty.html#QQmlProperty-3

        **QQmlProperty::QQmlProperty(QObject * obj , QQmlEngine * engine )**

        Creates a QQmlProperty for the default property of **obj** using the
        environment for instantiating QML components that is provided by
        **engine**. If there is no default property, an invalid QQmlProperty
        will be created.
        """
        ...

    @typing.overload
    def __init__(self, a0: QtCore.QObject, a1: str) -> None:
        """
        https://doc.qt.io/qt-6/qqmlproperty.html#QQmlProperty-4

        **QQmlProperty::QQmlProperty(QObject * obj , const QString & name )**

        Creates a QQmlProperty for the property **name** of **obj**.
        """
        ...

    @typing.overload
    def __init__(self, a0: QtCore.QObject, a1: str, a2: QQmlContext) -> None:
        """
        https://doc.qt.io/qt-6/qqmlproperty.html#QQmlProperty-5

        **QQmlProperty::QQmlProperty(QObject * obj , const QString & name ,
        QQmlContext * ctxt )**

        Creates a QQmlProperty for the property **name** of **obj** using the
        **context**  **ctxt**.

        Creating a QQmlProperty without a context will render some properties -
        like attached properties - inaccessible.
        """
        ...

    @typing.overload
    def __init__(self, a0: QtCore.QObject, a1: str, a2: QQmlEngine) -> None:
        """
        https://doc.qt.io/qt-6/qqmlproperty.html#QQmlProperty-6

        **QQmlProperty::QQmlProperty(QObject * obj , const QString & name ,
        QQmlEngine * engine )**

        Creates a QQmlProperty for the property **name** of **obj** using the
        environment for instantiating QML components that is provided by
        **engine**.
        """
        ...

    @typing.overload
    def __init__(self, a0: "QQmlProperty") -> None:
        """
        https://doc.qt.io/qt-6/qqmlproperty.html#QQmlProperty-7

        **QQmlProperty::QQmlProperty(const QQmlProperty & other )**

        Create a copy of **other**.
        """
        ...

    def method(self) -> QtCore.QMetaMethod:
        """
        https://doc.qt.io/qt-6/qqmlproperty.html#method

        **QMetaMethod QQmlProperty::method() const**

        Return the **QMetaMethod**  for this property if it is a
        **SignalProperty** , otherwise returns an invalid **QMetaMethod** .
        """
        ...

    def property(self) -> QtCore.QMetaProperty:
        """
        https://doc.qt.io/qt-6/qqmlproperty.html#property

        **QMetaProperty QQmlProperty::property() const**

        Returns the **Qt property**  associated with this QML property.
        """
        ...

    def index(self) -> int:
        """
        https://doc.qt.io/qt-6/qqmlproperty.html#index

        **int QQmlProperty::index() const**

        Return the Qt metaobject index of the property.
        """
        ...

    def object(self) -> QtCore.QObject:
        """
        https://doc.qt.io/qt-6/qqmlproperty.html#object

        **QObject *QQmlProperty::object() const**

        Returns the **QQmlProperty** 's **QObject** .

        **Note:** Getter function for property object.
        """
        ...

    def isResettable(self) -> bool:
        """
        https://doc.qt.io/qt-6/qqmlproperty.html#isResettable

        **bool QQmlProperty::isResettable() const**

        Returns true if the property is resettable, otherwise false.
        """
        ...

    def isDesignable(self) -> bool:
        """
        https://doc.qt.io/qt-6/qqmlproperty.html#isDesignable

        **bool QQmlProperty::isDesignable() const**

        Returns true if the property is designable, otherwise false.
        """
        ...

    def isWritable(self) -> bool:
        """
        https://doc.qt.io/qt-6/qqmlproperty.html#isWritable

        **bool QQmlProperty::isWritable() const**

        Returns true if the property is writable, otherwise false.
        """
        ...

    @typing.overload
    def connectNotifySignal(self, slot: PYQT_SLOT) -> bool:
        """
        https://doc.qt.io/qt-6/qqmlproperty.html#connectNotifySignal

        **bool QQmlProperty::connectNotifySignal(QObject * dest , const char *
        slot ) const**

        Connects the property's change notifier signal to the specified **slot**
        of the **dest** object and returns true. Returns false if this
        metaproperty does not represent a regular Qt property or if it has no
        change notifier signal, or if the **dest** object does not have the
        specified **slot**.

        **Note:** **slot** should be passed using the SLOT() macro so it is
        correctly identified.
        """
        ...

    @typing.overload
    def connectNotifySignal(self, dest: QtCore.QObject, method: int) -> bool:
        """
        https://doc.qt.io/qt-6/qqmlproperty.html#connectNotifySignal-1

        **bool QQmlProperty::connectNotifySignal(QObject * dest , int method )
        const**

        Connects the property's change notifier signal to the specified
        **method** of the **dest** object and returns true. Returns false if
        this metaproperty does not represent a regular Qt property or if it has
        no change notifier signal, or if the **dest** object does not have the
        specified **method**.
        """
        ...

    def needsNotifySignal(self) -> bool:
        """
        https://doc.qt.io/qt-6/qqmlproperty.html#needsNotifySignal

        **bool QQmlProperty::needsNotifySignal() const**

        Returns true if the property needs a change notifier signal for bindings
        to remain upto date, false otherwise.

        Some properties, such as attached properties or those whose value never
        changes, do not require a change notifier.
        """
        ...

    def hasNotifySignal(self) -> bool:
        """
        https://doc.qt.io/qt-6/qqmlproperty.html#hasNotifySignal

        **bool QQmlProperty::hasNotifySignal() const**

        Returns true if the property has a change notifier signal, otherwise
        false.
        """
        ...

    def reset(self) -> bool:
        """
        https://doc.qt.io/qt-6/qqmlproperty.html#reset

        **bool QQmlProperty::reset() const**

        Resets the property and returns true if the property is resettable. If
        the property is not resettable, nothing happens and false is returned.
        """
        ...

    @typing.overload
    def write(self, a0: typing.Any) -> bool:
        """
        https://doc.qt.io/qt-6/qqmlproperty.html#write

        **bool QQmlProperty::write(const QVariant & value ) const**

        Sets the property value to **value**. Returns `true` on success, or
        `false` if the property can't be set because the **value** is the wrong
        type, for example.
        """
        ...

    @typing.overload
    @staticmethod
    def write(a0: QtCore.QObject, a1: str, a2: typing.Any) -> bool:
        """
        https://doc.qt.io/qt-6/qqmlproperty.html#write-1

        **[static] bool QQmlProperty::write(QObject * object , const QString &
        name , const QVariant & value )**

        Writes **value** to the **name** property of **object**. This method is
        equivalent to:

        **QQmlProperty**  p(object, name);
            p.write(value);

        Returns `true` on success, `false` otherwise.
        """
        ...

    @typing.overload
    @staticmethod
    def write(a0: QtCore.QObject, a1: str, a2: typing.Any, a3: QQmlContext) -> bool:
        """
        https://doc.qt.io/qt-6/qqmlproperty.html#write-2

        **[static] bool QQmlProperty::write(QObject * object , const QString &
        name , const QVariant & value , QQmlContext * ctxt )**

        Writes **value** to the **name** property of **object** using the
        **context**  **ctxt**. This method is equivalent to:

        **QQmlProperty**  p(object, name, ctxt);
            p.write(value);

        Returns `true` on success, `false` otherwise.
        """
        ...

    @typing.overload
    @staticmethod
    def write(a0: QtCore.QObject, a1: str, a2: typing.Any, a3: QQmlEngine) -> bool:
        """
        https://doc.qt.io/qt-6/qqmlproperty.html#write-3

        **[static] bool QQmlProperty::write(QObject * object , const QString &
        name , const QVariant & value , QQmlEngine * engine )**

        Writes **value** to the **name** property of **object** using the
        environment for instantiating QML components that is provided by
        **engine**. This method is equivalent to:

        **QQmlProperty**  p(object, name, engine);
            p.write(value);

        Returns `true` on success, `false` otherwise.
        """
        ...

    @typing.overload
    def read(self) -> typing.Any:
        """
        https://doc.qt.io/qt-6/qqmlproperty.html#read

        **QVariant QQmlProperty::read() const**

        Returns the property value.
        """
        ...

    @typing.overload
    @staticmethod
    def read(a0: QtCore.QObject, a1: str) -> typing.Any:
        """
        https://doc.qt.io/qt-6/qqmlproperty.html#read-1

        **[static] QVariant QQmlProperty::read(const QObject * object , const
        QString & name )**

        Return the **name** property value of **object**. This method is
        equivalent to:

        **QQmlProperty**  p(object, name);
            p.read();
        """
        ...

    @typing.overload
    @staticmethod
    def read(a0: QtCore.QObject, a1: str, a2: QQmlContext) -> typing.Any:
        """
        https://doc.qt.io/qt-6/qqmlproperty.html#read-2

        **[static] QVariant QQmlProperty::read(const QObject * object , const
        QString & name , QQmlContext * ctxt )**

        Return the **name** property value of **object** using the **context**
        **ctxt**. This method is equivalent to:

        **QQmlProperty**  p(object, name, context);
            p.read();
        """
        ...

    @typing.overload
    @staticmethod
    def read(a0: QtCore.QObject, a1: str, a2: QQmlEngine) -> typing.Any:
        """
        https://doc.qt.io/qt-6/qqmlproperty.html#read-3

        **[static] QVariant QQmlProperty::read(const QObject * object , const
        QString & name , QQmlEngine * engine )**

        Return the **name** property value of **object** using the environment
        for instantiating QML components that is provided by **engine**. . This
        method is equivalent to:

        **QQmlProperty**  p(object, name, engine);
            p.read();
        """
        ...

    def name(self) -> str:
        """
        https://doc.qt.io/qt-6/qqmlproperty.html#name

        **QString QQmlProperty::name() const**

        Return the name of this QML property.

        **Note:** Getter function for property name.
        """
        ...

    def propertyMetaType(self) -> QtCore.QMetaType:
        """
        https://doc.qt.io/qt-6/qqmlproperty.html#propertyMetaType

        **QMetaType QQmlProperty::propertyMetaType() const**

        Returns the metatype of the property.

        **See also** **propertyType** .
        """
        ...

    def propertyTypeName(self) -> str:
        """
        https://doc.qt.io/qt-6/qqmlproperty.html#propertyTypeName

        **const char *QQmlProperty::propertyTypeName() const**

        Returns the type name of the property, or 0 if the property has no type
        name.
        """
        ...

    def propertyTypeCategory(self) -> "QQmlProperty.PropertyTypeCategory":
        """
        https://doc.qt.io/qt-6/qqmlproperty.html#propertyTypeCategory

        **QQmlProperty::PropertyTypeCategory
        QQmlProperty::propertyTypeCategory() const**

        Returns the property category.
        """
        ...

    def propertyType(self) -> int:
        """
        https://doc.qt.io/qt-6/qqmlproperty.html#propertyType

        **int QQmlProperty::propertyType() const**

        Returns the metatype id of the property, or **QMetaType::UnknownType**
        if the property has no metatype.

        **See also** **propertyMetaType** .
        """
        ...

    def isBindable(self) -> bool:
        ...

    def isSignalProperty(self) -> bool:
        """
        https://doc.qt.io/qt-6/qqmlproperty.html#isSignalProperty

        **bool QQmlProperty::isSignalProperty() const**

        Returns true if this **QQmlProperty**  represents a QML signal property.
        """
        ...

    def isProperty(self) -> bool:
        """
        https://doc.qt.io/qt-6/qqmlproperty.html#isProperty

        **bool QQmlProperty::isProperty() const**

        Returns true if this **QQmlProperty**  represents a regular Qt property.
        """
        ...

    def isValid(self) -> bool:
        """
        https://doc.qt.io/qt-6/qqmlproperty.html#isValid

        **bool QQmlProperty::isValid() const**

        Returns true if the **QQmlProperty**  refers to a valid property,
        otherwise false.
        """
        ...

    def type(self) -> "QQmlProperty.Type":
        """
        https://doc.qt.io/qt-6/qqmlproperty.html#type

        **QQmlProperty::Type QQmlProperty::type() const**

        Returns the type of the property.
        """
        ...

    def __hash__(self) -> int:
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
from PyQt6 import QtCore
from PyQt6.QtGui import *
import enum


class QScrollEvent(QtCore.QEvent):
    """
    https://doc.qt.io/qt-6/qscrollevent.html

    **Detailed Description**

    The scroll event is sent to indicate that the receiver should be scrolled.
    Usually the receiver should be something visual like **QWidget**  or
    **QGraphicsObject** .

    Some care should be taken that no conflicting QScrollEvents are sent from
    two sources. Using **QScroller::scrollTo**  is save however.

    **See also** **QScrollPrepareEvent**  and **QScroller** .
    """

    class ScrollState(enum.Enum):
        ScrollStarted: QScrollEvent = ...
        ScrollUpdated: QScrollEvent = ...
        ScrollFinished: QScrollEvent = ...

    def __init__(
        self,
        contentPos: QtCore.QPointF,
        overshoot: QtCore.QPointF,
        scrollState: "QScrollEvent.ScrollState",
    ) -> None:
        """
        https://doc.qt.io/qt-6/qscrollevent.html#QScrollEvent-2

        **QScrollEvent::QScrollEvent(const QPointF & contentPos , const QPointF
        & overshootDistance , QScrollEvent::ScrollState scrollState )**

        Creates a new QScrollEvent **contentPos** is the new content position,
        **overshootDistance** is the new overshoot distance while
        **scrollState** indicates if this scroll event is the first one, the
        last one or some event in between.
        """
        ...

    def clone(self) -> "QScrollEvent":
        ...

    def scrollState(self) -> "QScrollEvent.ScrollState":
        """
        https://doc.qt.io/qt-6/qscrollevent.html#scrollState

        **QScrollEvent::ScrollState QScrollEvent::scrollState() const**

        Returns the current scroll state as a combination of ScrollStateFlag
        values. **ScrollStarted**  (or **ScrollFinished** ) will be set, if this
        scroll event is the first (or last) event in a scrolling activity.
        Please note that both values can be set at the same time, if the
        activity consists of a single **QScrollEvent** . All other scroll events
        in between will have their state set to **ScrollUpdated** .

        A widget could for example revert selections when scrolling is started
        and stopped.
        """
        ...

    def overshootDistance(self) -> QtCore.QPointF:
        """
        https://doc.qt.io/qt-6/qscrollevent.html#overshootDistance

        **QPointF QScrollEvent::overshootDistance() const**

        Returns the new overshoot distance. See **QScroller**  for an
        explanation of the term overshoot.

        **See also** **QScroller** .
        """
        ...

    def contentPos(self) -> QtCore.QPointF:
        """
        https://doc.qt.io/qt-6/qscrollevent.html#contentPos

        **QPointF QScrollEvent::contentPos() const**

        Returns the new scroll position.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import PyQt6.sip
from PyQt6.QtNetwork import *
import enum


class QSsl(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qssl.html

    **Detailed Description**
    """

    class SupportedFeature(enum.Enum):
        CertificateVerification: QSsl = ...
        ClientSideAlpn: QSsl = ...
        ServerSideAlpn: QSsl = ...
        Ocsp: QSsl = ...
        Psk: QSsl = ...
        SessionTicket: QSsl = ...
        Alerts: QSsl = ...

    class ImplementedClass(enum.Enum):
        Key: QSsl = ...
        Certificate: QSsl = ...
        Socket: QSsl = ...
        DiffieHellman: QSsl = ...
        EllipticCurve: QSsl = ...
        Dtls: QSsl = ...
        DtlsCookie: QSsl = ...

    class AlertType(enum.Enum):
        CloseNotify: QSsl = ...
        UnexpectedMessage: QSsl = ...
        BadRecordMac: QSsl = ...
        RecordOverflow: QSsl = ...
        DecompressionFailure: QSsl = ...
        HandshakeFailure: QSsl = ...
        NoCertificate: QSsl = ...
        BadCertificate: QSsl = ...
        UnsupportedCertificate: QSsl = ...
        CertificateRevoked: QSsl = ...
        CertificateExpired: QSsl = ...
        CertificateUnknown: QSsl = ...
        IllegalParameter: QSsl = ...
        UnknownCa: QSsl = ...
        AccessDenied: QSsl = ...
        DecodeError: QSsl = ...
        DecryptError: QSsl = ...
        ExportRestriction: QSsl = ...
        ProtocolVersion: QSsl = ...
        InsufficientSecurity: QSsl = ...
        InternalError: QSsl = ...
        InappropriateFallback: QSsl = ...
        UserCancelled: QSsl = ...
        NoRenegotiation: QSsl = ...
        MissingExtension: QSsl = ...
        UnsupportedExtension: QSsl = ...
        CertificateUnobtainable: QSsl = ...
        UnrecognizedName: QSsl = ...
        BadCertificateStatusResponse: QSsl = ...
        BadCertificateHashValue: QSsl = ...
        UnknownPskIdentity: QSsl = ...
        CertificateRequired: QSsl = ...
        NoApplicationProtocol: QSsl = ...
        UnknownAlertMessage: QSsl = ...

    class AlertLevel(enum.Enum):
        Warning: QSsl = ...
        Fatal: QSsl = ...
        Unknown: QSsl = ...

    class SslOption(enum.Flag):
        SslOptionDisableEmptyFragments: QSsl = ...
        SslOptionDisableSessionTickets: QSsl = ...
        SslOptionDisableCompression: QSsl = ...
        SslOptionDisableServerNameIndication: QSsl = ...
        SslOptionDisableLegacyRenegotiation: QSsl = ...
        SslOptionDisableSessionSharing: QSsl = ...
        SslOptionDisableSessionPersistence: QSsl = ...
        SslOptionDisableServerCipherPreference: QSsl = ...

    class SslProtocol(enum.Enum):
        UnknownProtocol: QSsl = ...
        TlsV1_0: QSsl = ...
        TlsV1_0OrLater: QSsl = ...
        TlsV1_1: QSsl = ...
        TlsV1_1OrLater: QSsl = ...
        TlsV1_2: QSsl = ...
        TlsV1_2OrLater: QSsl = ...
        AnyProtocol: QSsl = ...
        SecureProtocols: QSsl = ...
        DtlsV1_0: QSsl = ...
        DtlsV1_0OrLater: QSsl = ...
        DtlsV1_2: QSsl = ...
        DtlsV1_2OrLater: QSsl = ...
        TlsV1_3: QSsl = ...
        TlsV1_3OrLater: QSsl = ...

    class AlternativeNameEntryType(enum.Enum):
        EmailEntry: QSsl = ...
        DnsEntry: QSsl = ...
        IpAddressEntry: QSsl = ...

    class KeyAlgorithm(enum.Enum):
        Opaque: QSsl = ...
        Rsa: QSsl = ...
        Dsa: QSsl = ...
        Ec: QSsl = ...
        Dh: QSsl = ...

    class EncodingFormat(enum.Enum):
        Pem: QSsl = ...
        Der: QSsl = ...

    class KeyType(enum.Enum):
        PrivateKey: QSsl = ...
        PublicKey: QSsl = ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6 import QtGui
from PyQt6 import QtCore
from PyQt6.QtWidgets import *


class QGroupBox(QWidget):
    """
    https://doc.qt.io/qt-6/qgroupbox.html

    **Detailed Description**

    ![](images/windows-groupbox.png)

    A group box provides a frame, a title on top, a keyboard shortcut, and
    displays various other widgets inside itself. The keyboard shortcut moves
    keyboard focus to one of the group box's child widgets.

    QGroupBox also lets you set the **title**  (normally set in the constructor)
    and the title's **alignment** . Group boxes can be **checkable** . Child
    widgets in checkable group boxes are enabled or disabled depending on
    whether or not the group box is **checked** .

    You can minimize the space consumption of a group box by enabling the
    **flat**  property. In most **styles** , enabling this property results in
    the removal of the left, right and bottom edges of the frame.

    QGroupBox doesn't automatically lay out the child widgets (which are often
    **QCheckBox** es or **QRadioButton** s but can be any widgets). The
    following example shows how we can set up a QGroupBox with a layout:

    **QGroupBox**  *groupBox = new **QGroupBox** (tr("Exclusive Radio
    Buttons"));

            **QRadioButton**  *radio1 = new **QRadioButton**
    (tr("&Radio button 1"));
            **QRadioButton**  *radio2 = new
    **QRadioButton** (tr("R&adio button 2"));
            **QRadioButton**  *radio3
    = new **QRadioButton** (tr("Ra&dio button 3"));
    radio1->setChecked(true);

            **QVBoxLayout**  *vbox = new
    **QVBoxLayout** ;
            vbox->addWidget(radio1);
    vbox->addWidget(radio2);
            vbox->addWidget(radio3);
    vbox->addStretch(1);
            groupBox->setLayout(vbox);

    **See also** **QButtonGroup**  and **Group Box Example** .
    """

    @typing.overload
    def __init__(self, parent: typing.Optional[QWidget] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qgroupbox.html#QGroupBox

        **QGroupBox::QGroupBox(QWidget * parent = nullptr)**

        Constructs a group box widget with the given **parent** but with no
        title.
        """
        ...

    @typing.overload
    def __init__(self, title: str, parent: typing.Optional[QWidget] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qgroupbox.html#QGroupBox-1

        **QGroupBox::QGroupBox(const QString & title , QWidget * parent =
        nullptr)**

        Constructs a group box with the given **title** and **parent**.
        """
        ...

    def mouseReleaseEvent(self, event: QtGui.QMouseEvent) -> None:
        """
        https://doc.qt.io/qt-6/qgroupbox.html#mouseReleaseEvent

        **[override virtual protected] void
        QGroupBox::mouseReleaseEvent(QMouseEvent * event )**

        Reimplements: **QWidget::mouseReleaseEvent** (QMouseEvent *event).
        """
        ...

    def mouseMoveEvent(self, event: QtGui.QMouseEvent) -> None:
        """
        https://doc.qt.io/qt-6/qgroupbox.html#mouseMoveEvent

        **[override virtual protected] void
        QGroupBox::mouseMoveEvent(QMouseEvent * event )**

        Reimplements: **QWidget::mouseMoveEvent** (QMouseEvent *event).
        """
        ...

    def mousePressEvent(self, event: QtGui.QMouseEvent) -> None:
        """
        https://doc.qt.io/qt-6/qgroupbox.html#mousePressEvent

        **[override virtual protected] void
        QGroupBox::mousePressEvent(QMouseEvent * event )**

        Reimplements: **QWidget::mousePressEvent** (QMouseEvent *event).
        """
        ...

    def changeEvent(self, a0: QtCore.QEvent) -> None:
        """
        https://doc.qt.io/qt-6/qgroupbox.html#changeEvent

        **[override virtual protected] void QGroupBox::changeEvent(QEvent * ev
        )**

        Reimplements: **QWidget::changeEvent** (QEvent *event).
        """
        ...

    def focusInEvent(self, a0: QtGui.QFocusEvent) -> None:
        """
        https://doc.qt.io/qt-6/qgroupbox.html#focusInEvent

        **[override virtual protected] void QGroupBox::focusInEvent(QFocusEvent
        * fe )**

        Reimplements: **QWidget::focusInEvent** (QFocusEvent *event).
        """
        ...

    def paintEvent(self, a0: QtGui.QPaintEvent) -> None:
        """
        https://doc.qt.io/qt-6/qgroupbox.html#paintEvent

        **[override virtual protected] void QGroupBox::paintEvent(QPaintEvent *
        event )**

        Reimplements: **QWidget::paintEvent** (QPaintEvent *event).
        """
        ...

    def resizeEvent(self, a0: QtGui.QResizeEvent) -> None:
        """
        https://doc.qt.io/qt-6/qgroupbox.html#resizeEvent

        **[override virtual protected] void QGroupBox::resizeEvent(QResizeEvent
        * e )**

        Reimplements: **QWidget::resizeEvent** (QResizeEvent *event).
        """
        ...

    def childEvent(self, a0: QtCore.QChildEvent) -> None:
        """
        https://doc.qt.io/qt-6/qgroupbox.html#childEvent

        **[override virtual protected] void QGroupBox::childEvent(QChildEvent *
        c )**

        Reimplements: **QObject::childEvent** (QChildEvent *event).
        """
        ...

    def event(self, a0: QtCore.QEvent) -> bool:
        """
        https://doc.qt.io/qt-6/qgroupbox.html#event

        **[override virtual protected] bool QGroupBox::event(QEvent * e )**

        Reimplements: **QWidget::event** (QEvent *event).
        """
        ...

    def initStyleOption(self, option: "QStyleOptionGroupBox") -> None:
        """
        https://doc.qt.io/qt-6/qgroupbox.html#initStyleOption

        **[virtual protected] void
        QGroupBox::initStyleOption(QStyleOptionGroupBox * option ) const**

        Initialize **option** with the values from this **QGroupBox** . This
        method is useful for subclasses when they need a
        **QStyleOptionGroupBox** , but don't want to fill in all the information
        themselves.

        **See also** **QStyleOption::initFrom** ().
        """
        ...

    def setChecked(self, b: bool) -> None:
        """
        https://doc.qt.io/qt-6/qgroupbox.html#checked-prop

        **checked : bool**

        This property holds whether the group box is checked

        If the group box is checkable, it is displayed with a check box. If the
        check box is checked, the group box's children are enabled; otherwise,
        the children are disabled and are inaccessible to the user.

        By default, checkable group boxes are also checked.

        **Access functions:**

        bool **isChecked** () const
        void **setChecked** (bool **checked** )

        **Notifier signal:**

        void ****toggled** ** (bool **on** )

        **See also** **checkable** .
        """
        ...

    def isChecked(self) -> bool:
        ...

    def setCheckable(self, b: bool) -> None:
        """
        https://doc.qt.io/qt-6/qgroupbox.html#checkable-prop

        **checkable : bool**

        This property holds whether the group box has a checkbox in its title

        If this property is `true`, the group box displays its title using a
        checkbox in place of an ordinary label. If the checkbox is checked, the
        group box's children are enabled; otherwise, they are disabled and
        inaccessible.

        By default, group boxes are not checkable.

        If this property is enabled for a group box, it will also be initially
        checked to ensure that its contents are enabled.

        **Access functions:**

        bool **isCheckable** () const
        void **setCheckable** (bool
        **checkable** )

        **See also** **checked** .
        """
        ...

    def isCheckable(self) -> bool:
        ...

    def setFlat(self, b: bool) -> None:
        """
        https://doc.qt.io/qt-6/qgroupbox.html#flat-prop

        **flat : bool**

        This property holds whether the group box is painted flat or has a frame

        A group box usually consists of a surrounding frame with a title at the
        top. If this property is enabled, only the top part of the frame is
        drawn in most styles; otherwise, the whole frame is drawn.

        By default, this property is disabled, i.e., group boxes are not flat
        unless explicitly specified.

        **Note:** In some styles, flat and non-flat group boxes have similar
        representations and may not be as distinguishable as they are in other
        styles.

        **Access functions:**

        bool **isFlat** () const
        void **setFlat** (bool **flat** )

        **See also** **title** .
        """
        ...

    def isFlat(self) -> bool:
        ...

    def minimumSizeHint(self) -> QtCore.QSize:
        """
        https://doc.qt.io/qt-6/qgroupbox.html#minimumSizeHint

        **[override virtual] QSize QGroupBox::minimumSizeHint() const**

        Reimplements an access function for property:
        **QWidget::minimumSizeHint** .
        """
        ...

    def setAlignment(self, a0: int) -> None:
        """
        https://doc.qt.io/qt-6/qgroupbox.html#alignment-prop

        **alignment : Qt::Alignment**

        This property holds the alignment of the group box title.

        Most styles place the title at the top of the frame. The horizontal
        alignment of the title can be specified using single values from the
        following list:

        * **Qt::AlignLeft**  aligns the title text with the left-hand side of
        the group box.
          * **Qt::AlignRight**  aligns the title text with the
        right-hand side of the group box.
          * **Qt::AlignHCenter**  aligns the
        title text with the horizontal center of the group box.

        The default alignment is **Qt::AlignLeft** .

        **Access functions:**

        Qt::Alignment **alignment** () const
        void **setAlignment** (int
        **alignment** )

        **See also** **Qt::Alignment** .
        """
        ...

    def alignment(self) -> QtCore.Qt.AlignmentFlag:
        """
        https://doc.qt.io/qt-6/qgroupbox.html#alignment-prop

        **alignment : Qt::Alignment**

        This property holds the alignment of the group box title.

        Most styles place the title at the top of the frame. The horizontal
        alignment of the title can be specified using single values from the
        following list:

        * **Qt::AlignLeft**  aligns the title text with the left-hand side of
        the group box.
          * **Qt::AlignRight**  aligns the title text with the
        right-hand side of the group box.
          * **Qt::AlignHCenter**  aligns the
        title text with the horizontal center of the group box.

        The default alignment is **Qt::AlignLeft** .

        **Access functions:**

        Qt::Alignment **alignment** () const
        void **setAlignment** (int
        **alignment** )

        **See also** **Qt::Alignment** .
        """
        ...

    def setTitle(self, a0: str) -> None:
        """
        https://doc.qt.io/qt-6/qgroupbox.html#title-prop

        **title : QString**

        This property holds the group box title text

        The group box title text will have a keyboard shortcut if the title
        contains an ampersand ('&') followed by a letter.

        g->setTitle("&User information");

        In the example above, **Alt+U** moves the keyboard focus to the group
        box. See the **QShortcut**  documentation for details (to display an
        actual ampersand, use '&&').

        There is no default title text.

        **Access functions:**

        QString **title** () const
        void **setTitle** (const QString &
        **title** )

        **See also** **alignment** .

        **Member Function Documentation**
        """
        ...

    def title(self) -> str:
        """
        https://doc.qt.io/qt-6/qgroupbox.html#title-prop

        **title : QString**

        This property holds the group box title text

        The group box title text will have a keyboard shortcut if the title
        contains an ampersand ('&') followed by a letter.

        g->setTitle("&User information");

        In the example above, **Alt+U** moves the keyboard focus to the group
        box. See the **QShortcut**  documentation for details (to display an
        actual ampersand, use '&&').

        There is no default title text.

        **Access functions:**

        QString **title** () const
        void **setTitle** (const QString &
        **title** )

        **See also** **alignment** .

        **Member Function Documentation**
        """
        ...

    @property
    def clicked(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qgroupbox.html#clicked

        **[signal] void QGroupBox::clicked(bool checked = false)**

        This signal is emitted when the check box is activated (i.e., pressed
        down then released while the mouse cursor is inside the button), or when
        the shortcut key is typed. Notably, this signal is **not** emitted if
        you call **setChecked** ().

        If the check box is checked, **checked** is true; it is false if the
        check box is unchecked.

        **See also** **checkable** , **toggled** (), and **checked** .
        """
        ...

    @property
    def toggled(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qgroupbox.html#toggled

        **[signal] void QGroupBox::toggled(bool on )**

        If the group box is checkable, this signal is emitted when the check box
        is toggled. **on** is true if the check box is checked; otherwise, it is
        false.

        **Note:** Notifier signal for property **checked** .

        **See also** **checkable** .
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6 import QtCore
from PyQt6.QtQml import *


class QQmlListReference(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qqmllistreference.html

    **Detailed Description**

    QQmlListReference allows C++ programs to read from, and assign values to a
    QML list property in a simple and type-safe way. A QQmlListReference can be
    created by passing an object and property name or through a **QQmlProperty**
    instance. These two are equivalent:

    **QQmlListReference**  ref1(object, "children");

        **QQmlProperty**
    ref2(object, "children");
        **QQmlListReference**  ref2 =
    qvariant_cast<**QQmlListReference** >(ref2.read());

    Not all QML list properties support all operations. A set of methods,
    **canAppend** (), **canAt** (), **canClear** () and **canCount** () allow
    programs to query whether an operation is supported on a given property.

    QML list properties are type-safe. Only **QObject** 's that derive from the
    correct base class can be assigned to the list. The **listElementType** ()
    method can be used to query the **QMetaObject**  of the **QObject**  type
    supported. Attempting to add objects of the incorrect type to a list
    property will fail.

    Like with normal lists, when accessing a list element by index, it is the
    callers responsibility to ensure that it does not request an out of range
    element using the **count** () method before calling **at** ().
    """

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qqmllistreference.html#QQmlListReference

        **QQmlListReference::QQmlListReference()**

        Constructs an invalid instance.
        """
        ...

    @typing.overload
    def __init__(
        self,
        a0: QtCore.QObject,
        property: str,
        engine: typing.Optional[QQmlEngine] = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qqmllistreference.html#QQmlListReference-1

        **[since 6.1] QQmlListReference::QQmlListReference(const QVariant &
        variant , QQmlEngine * engine = nullptr)**

        Constructs a QQmlListReference from a **QVariant**  **variant**
        containing a **QQmlListProperty** . If **variant** does not contain a
        list property, an invalid QQmlListReference is created. If the object
        owning the list property is destroyed after the reference is
        constructed, it will automatically become invalid. That is, it is safe
        to hold QQmlListReference instances even after the object is deleted.

        The **engine** is required to look up the element type, which may be a
        dynamically created QML type. If it's omitted, only pre-registered types
        are available. The element type is needed when inserting values into the
        list and when the value meta type is explicitly retrieved.

        This function was introduced in Qt 6.1.
        """
        ...

    @typing.overload
    def __init__(self, a0: "QQmlListReference") -> None:
        """
        https://doc.qt.io/qt-6/qqmllistreference.html#QQmlListReference-2

        **QQmlListReference::QQmlListReference(QObject * object , const char *
        property , QQmlEngine * engine = nullptr)**

        Constructs a QQmlListReference for **object** 's **property**. If
        **property** is not a list property, an invalid QQmlListReference is
        created. If **object** is destroyed after the reference is constructed,
        it will automatically become invalid. That is, it is safe to hold
        QQmlListReference instances even after **object** is deleted.

        The **engine** is required to look up the element type, which may be a
        dynamically created QML type. If it's omitted, only pre-registered types
        are available. The element type is needed when inserting values into the
        list and when the value meta type is explicitly retrieved.
        """
        ...

    @typing.overload
    def __init__(
        self, variant: typing.Any, engine: typing.Optional[QQmlEngine] = ...
    ) -> None:
        """
        https://doc.qt.io/qt-6/qqmllistreference.html#QQmlListReference

        **QQmlListReference::QQmlListReference()**

        Constructs an invalid instance.
        """
        ...

    def removeLast(self) -> bool:
        """
        https://doc.qt.io/qt-6/qqmllistreference.html#removeLast

        **bool QQmlListReference::removeLast() const**

        Removes the last item in the list. Returns true if the operation
        succeeded, otherwise false.

        **See also** **canRemoveLast** ().
        """
        ...

    def replace(self, a0: int, a1: QtCore.QObject) -> bool:
        """
        https://doc.qt.io/qt-6/qqmllistreference.html#replace

        **bool QQmlListReference::replace(qsizetype index , QObject * object )
        const**

        Replaces the item at **index** in the list with **object**. Returns true
        if the operation succeeded, otherwise false.

        **See also** **canReplace** ().
        """
        ...

    def canRemoveLast(self) -> bool:
        """
        https://doc.qt.io/qt-6/qqmllistreference.html#canRemoveLast

        **bool QQmlListReference::canRemoveLast() const**

        Returns true if the last item can be removed from the list property,
        otherwise false. Returns false if the reference is invalid.

        **See also** **removeLast** ().
        """
        ...

    def canReplace(self) -> bool:
        """
        https://doc.qt.io/qt-6/qqmllistreference.html#canReplace

        **bool QQmlListReference::canReplace() const**

        Returns true if items in the list property can be replaced, otherwise
        false. Returns false if the reference is invalid.

        **See also** **replace** ().
        """
        ...

    def __len__(self) -> int:
        ...

    def count(self) -> int:
        """
        https://doc.qt.io/qt-6/qqmllistreference.html#count

        **qsizetype QQmlListReference::count() const**

        Returns the number of objects in the list, or 0 if the operation failed.
        """
        ...

    def clear(self) -> bool:
        """
        https://doc.qt.io/qt-6/qqmllistreference.html#clear

        **bool QQmlListReference::clear() const**

        Clears the list. Returns true if the operation succeeded, otherwise
        false.

        **See also** **canClear** ().
        """
        ...

    def at(self, a0: int) -> QtCore.QObject:
        """
        https://doc.qt.io/qt-6/qqmllistreference.html#at

        **QObject *QQmlListReference::at(qsizetype index ) const**

        Returns the list element at **index** , or 0 if the operation failed.

        **See also** **canAt** ().
        """
        ...

    def append(self, a0: QtCore.QObject) -> bool:
        """
        https://doc.qt.io/qt-6/qqmllistreference.html#append

        **bool QQmlListReference::append(QObject * object ) const**

        Appends **object** to the list. Returns true if the operation succeeded,
        otherwise false.

        **See also** **canAppend** ().
        """
        ...

    def isReadable(self) -> bool:
        """
        https://doc.qt.io/qt-6/qqmllistreference.html#isReadable

        **bool QQmlListReference::isReadable() const**

        Return true if **at** () and **count** () are implemented, so you can
        access the elements.

        **See also** **isManipulable** (), **at** (), and **count** ().
        """
        ...

    def isManipulable(self) -> bool:
        """
        https://doc.qt.io/qt-6/qqmllistreference.html#isManipulable

        **bool QQmlListReference::isManipulable() const**

        Return true if **at** (), **count** (), **append** (), and either
        **clear** () or **removeLast** () are implemented, so you can manipulate
        the list.

        Mind that **replace** () and **removeLast** () can be emulated by
        stashing all items and rebuilding the list using **clear** () and
        **append** (). Therefore, they are not required for the list to be
        manipulable. Furthermore, **clear** () can be emulated using
        **removeLast** ().

        **See also** **isReadable** (), **at** (), **count** (), **append** (),
        **clear** (), **replace** (), and **removeLast** ().
        """
        ...

    def canCount(self) -> bool:
        """
        https://doc.qt.io/qt-6/qqmllistreference.html#canCount

        **bool QQmlListReference::canCount() const**

        Returns true if the list property can be queried for its element count,
        otherwise false. Returns false if the reference is invalid.

        **See also** **count** ().
        """
        ...

    def canClear(self) -> bool:
        """
        https://doc.qt.io/qt-6/qqmllistreference.html#canClear

        **bool QQmlListReference::canClear() const**

        Returns true if the list property can be cleared, otherwise false.
        Returns false if the reference is invalid.

        **See also** **clear** ().
        """
        ...

    def canAt(self) -> bool:
        """
        https://doc.qt.io/qt-6/qqmllistreference.html#canAt

        **bool QQmlListReference::canAt() const**

        Returns true if the list property can queried by index, otherwise false.
        Returns false if the reference is invalid.

        **See also** **at** ().
        """
        ...

    def canAppend(self) -> bool:
        """
        https://doc.qt.io/qt-6/qqmllistreference.html#canAppend

        **bool QQmlListReference::canAppend() const**

        Returns true if the list property can be appended to, otherwise false.
        Returns false if the reference is invalid.

        **See also** **append** ().
        """
        ...

    def listElementType(self) -> QtCore.QMetaObject:
        """
        https://doc.qt.io/qt-6/qqmllistreference.html#listElementType

        **const QMetaObject *QQmlListReference::listElementType() const**

        Returns the **QMetaObject**  for the elements stored in the list
        property, or `nullptr` if the reference is invalid.

        The **QMetaObject**  can be used ahead of time to determine whether a
        given instance can be added to a list. If you didn't pass an engine on
        construction this may return nullptr.
        """
        ...

    def object(self) -> QtCore.QObject:
        """
        https://doc.qt.io/qt-6/qqmllistreference.html#object

        **QObject *QQmlListReference::object() const**

        Returns the list property's object. Returns `nullptr` if the reference
        is invalid.
        """
        ...

    def isValid(self) -> bool:
        """
        https://doc.qt.io/qt-6/qqmllistreference.html#isValid

        **bool QQmlListReference::isValid() const**

        Returns true if the instance refers to a valid list property, otherwise
        false.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6 import QtCore
from PyQt6.QtBluetooth import *
import enum


class QBluetoothServer(QtCore.QObject):
    """
    https://doc.qt.io/qt-6/qbluetoothserver.html

    **Detailed Description**

    QBluetoothServer is used to implement Bluetooth services over RFCOMM or
    L2cap.

    Start listening for incoming connections with **listen** (). Wait till the
    **newConnection** () signal is emitted when a new connection is established,
    and call **nextPendingConnection** () to get a **QBluetoothSocket**  for the
    new connection.

    To enable other devices to find your service, create a
    **QBluetoothServiceInfo**  with the applicable attributes for your service
    and register it using **QBluetoothServiceInfo::registerService** (). Call
    **serverPort** () to get the channel number that is being used.

    If the **QBluetoothServiceInfo::Protocol**  is not supported by a platform,
    **listen** () will return `false`. Android and WinRT only support RFCOMM for
    example.

    On iOS, this class cannot be used because the platform does not expose an
    API which may permit access to QBluetoothServer related features.

    **See also** **QBluetoothServiceInfo**  and **QBluetoothSocket** .
    """

    class Error(enum.Enum):
        NoError: QBluetoothServer = ...
        UnknownError: QBluetoothServer = ...
        PoweredOffError: QBluetoothServer = ...
        InputOutputError: QBluetoothServer = ...
        ServiceAlreadyRegisteredError: QBluetoothServer = ...
        UnsupportedProtocolError: QBluetoothServer = ...

    def __init__(
        self,
        serverType: "QBluetoothServiceInfo.Protocol",
        parent: typing.Optional[QtCore.QObject] = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qbluetoothserver.html#QBluetoothServer

        **QBluetoothServer::QBluetoothServer(QBluetoothServiceInfo::Protocol
        serverType , QObject * parent = nullptr)**

        Constructs a bluetooth server with **parent** and **serverType**.
        """
        ...

    def error(self) -> "QBluetoothServer.Error":
        """
        https://doc.qt.io/qt-6/qbluetoothserver.html#error

        **QBluetoothServer::Error QBluetoothServer::error() const**

        Returns the last error of the **QBluetoothServer** .
        """
        ...

    def serverType(self) -> "QBluetoothServiceInfo.Protocol":
        """
        https://doc.qt.io/qt-6/qbluetoothserver.html#serverType

        **QBluetoothServiceInfo::Protocol QBluetoothServer::serverType() const**

        Returns the type of the **QBluetoothServer** .
        """
        ...

    def securityFlags(self) -> QBluetooth.Security:
        """
        https://doc.qt.io/qt-6/qbluetoothserver.html#securityFlags

        **QBluetooth::SecurityFlags QBluetoothServer::securityFlags() const**

        Returns the Bluetooth security flags.

        **See also** **setSecurityFlags** ().
        """
        ...

    def setSecurityFlags(self, security: QBluetooth.Security) -> None:
        """
        https://doc.qt.io/qt-6/qbluetoothserver.html#setSecurityFlags

        **void QBluetoothServer::setSecurityFlags(QBluetooth::SecurityFlags
        security )**

        Sets the Bluetooth security flags to **security**. This function must be
        called before calling **listen** (). The Bluetooth link will always be
        encrypted when using Bluetooth 2.1 devices as encryption is mandatory.

        Android only supports two levels of security (secure and non-secure). If
        this flag is set to **QBluetooth::Security::NoSecurity**  the server
        object will not employ any authentication or encryption. Any other
        security flag combination will trigger a secure Bluetooth connection.

        On macOS, security flags are not supported and will be ignored.

        **See also** **securityFlags** ().
        """
        ...

    def serverPort(self) -> int:
        """
        https://doc.qt.io/qt-6/qbluetoothserver.html#serverPort

        **quint16 QBluetoothServer::serverPort() const**

        Returns the server port number.
        """
        ...

    def serverAddress(self) -> QBluetoothAddress:
        """
        https://doc.qt.io/qt-6/qbluetoothserver.html#serverAddress

        **QBluetoothAddress QBluetoothServer::serverAddress() const**

        Returns the server address.
        """
        ...

    def nextPendingConnection(self) -> "QBluetoothSocket":
        """
        https://doc.qt.io/qt-6/qbluetoothserver.html#nextPendingConnection

        **QBluetoothSocket *QBluetoothServer::nextPendingConnection()**

        Returns a pointer to the **QBluetoothSocket**  for the next pending
        connection. It is the callers responsibility to delete the pointer.
        """
        ...

    def hasPendingConnections(self) -> bool:
        """
        https://doc.qt.io/qt-6/qbluetoothserver.html#hasPendingConnections

        **bool QBluetoothServer::hasPendingConnections() const**

        Returns true if a connection is pending, otherwise false.
        """
        ...

    def maxPendingConnections(self) -> int:
        """
        https://doc.qt.io/qt-6/qbluetoothserver.html#maxPendingConnections

        **int QBluetoothServer::maxPendingConnections() const**

        Returns the maximum number of pending connections.

        **See also** **setMaxPendingConnections** ().
        """
        ...

    def setMaxPendingConnections(self, numConnections: int) -> None:
        """
        https://doc.qt.io/qt-6/qbluetoothserver.html#setMaxPendingConnections

        **void QBluetoothServer::setMaxPendingConnections(int numConnections )**

        Sets the maximum number of pending connections to **numConnections**. If
        the number of pending sockets exceeds this limit new sockets will be
        rejected.

        **See also** **maxPendingConnections** ().
        """
        ...

    def isListening(self) -> bool:
        """
        https://doc.qt.io/qt-6/qbluetoothserver.html#isListening

        **bool QBluetoothServer::isListening() const**

        Returns true if the server is listening for incoming connections,
        otherwise false.
        """
        ...

    @typing.overload
    def listen(self, address: QBluetoothAddress = ..., port: int = ...) -> bool:
        """
        https://doc.qt.io/qt-6/qbluetoothserver.html#listen

        **bool QBluetoothServer::listen(const QBluetoothAddress & address =
        QBluetoothAddress(), quint16 port = 0)**

        Start listening for incoming connections to **address** on **port**.
        **address** must be a local Bluetooth adapter address and **port** must
        be larger than zero and not be taken already by another Bluetooth server
        object. It is recommended to avoid setting a port number to enable the
        system to automatically choose a port.

        Returns `true` if the operation succeeded and the server is listening
        for incoming connections, otherwise returns `false`.

        If the server object is already listening for incoming connections this
        function always returns `false`. **close** () should be called before
        calling this function.

        **See also** **isListening** () and **newConnection** ().
        """
        ...

    @typing.overload
    def listen(
        self, uuid: "QBluetoothUuid", serviceName: str = ...
    ) -> "QBluetoothServiceInfo":
        """
        https://doc.qt.io/qt-6/qbluetoothserver.html#listen-1

        **QBluetoothServiceInfo QBluetoothServer::listen(const QBluetoothUuid &
        uuid , const QString & serviceName = QString())**

        Convenience function for registering an SPP service with **uuid** and
        **serviceName**. Because this function already registers the service,
        the **QBluetoothServiceInfo**  object which is returned can not be
        changed any more. To shutdown the server later on it is required to call
        **QBluetoothServiceInfo::unregisterService** () and **close** () on this
        server object.

        Returns a registered **QBluetoothServiceInfo**  instance if successful
        otherwise an invalid **QBluetoothServiceInfo** . This function always
        assumes that the default Bluetooth adapter should be used.

        If the server object is already listening for incoming connections this
        function returns an invalid **QBluetoothServiceInfo** .

        For an RFCOMM server this function is equivalent to following code
        snippet.

        **QBluetoothServiceInfo**  serviceInfo;
        serviceInfo.setAttribute(**QBluetoothServiceInfo** ::ServiceName,
        serviceName);
                **QBluetoothServiceInfo** ::Sequence
        browseSequence;
                browseSequence << **QVariant**
        ::fromValue(**QBluetoothUuid** (**QBluetoothUuid**
        ::ServiceClassUuid::PublicBrowseGroup));
        serviceInfo.setAttribute(**QBluetoothServiceInfo** ::BrowseGroupList,
        browseSequence);

                **QBluetoothServiceInfo** ::Sequence
        profileSequence;
                **QBluetoothServiceInfo** ::Sequence classId;
        classId << **QVariant** ::fromValue(**QBluetoothUuid**
        (**QBluetoothUuid** ::ServiceClassUuid::SerialPort));
                classId <<
        **QVariant** ::fromValue(**quint16** (0x100));
        profileSequence.append(**QVariant** ::fromValue(classId));
        serviceInfo.setAttribute(**QBluetoothServiceInfo**
        ::BluetoothProfileDescriptorList,
        profileSequence);

                classId.clear();
                //Android
        requires custom uuid to be set as service class
                classId <<
        **QVariant** ::fromValue(uuid);
                classId << **QVariant**
        ::fromValue(**QBluetoothUuid** (**QBluetoothUuid**
        ::ServiceClassUuid::SerialPort));
        serviceInfo.setAttribute(**QBluetoothServiceInfo** ::ServiceClassIds,
        classId);
                serviceInfo.setServiceUuid(uuid);
        **QBluetoothServiceInfo** ::Sequence protocolDescriptorList;
        **QBluetoothServiceInfo** ::Sequence protocol;
                protocol <<
        **QVariant** ::fromValue(**QBluetoothUuid** (**QBluetoothUuid**
        ::ProtocolUuid::L2cap));
                if (d->serverType ==
        **QBluetoothServiceInfo** ::L2capProtocol)
                    protocol <<
        **QVariant** ::fromValue(serverPort());
        protocolDescriptorList.append(**QVariant** ::fromValue(protocol));
        protocol.clear();
                protocol << **QVariant**
        ::fromValue(**QBluetoothUuid** (**QBluetoothUuid**
        ::ProtocolUuid::Rfcomm))
                         << **QVariant**
        ::fromValue(**quint8** (serverPort()));
        protocolDescriptorList.append(**QVariant** ::fromValue(protocol));
        serviceInfo.setAttribute(**QBluetoothServiceInfo**
        ::ProtocolDescriptorList,
        protocolDescriptorList);
                bool result =
        serviceInfo.registerService();

        **See also** **isListening** (), **newConnection** (), and **listen**
        ().
        """
        ...

    def close(self) -> None:
        """
        https://doc.qt.io/qt-6/qbluetoothserver.html#close

        **void QBluetoothServer::close()**

        Closes and resets the listening socket. Any already established
        **QBluetoothSocket**  continues to operate and must be separately
        **closed** .
        """
        ...

    @property
    def errorOccurred(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qbluetoothserver.html#errorOccurred

        **[signal, since 6.2] void
        QBluetoothServer::errorOccurred(QBluetoothServer::Error error )**

        This signal is emitted when an **error** occurs.

        This function was introduced in Qt 6.2.

        **See also** **error** () and **QBluetoothServer::Error** .
        """
        ...

    @property
    def newConnection(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qbluetoothserver.html#newConnection

        **[signal] void QBluetoothServer::newConnection()**

        This signal is emitted when a new connection is available.

        The connected slot should call **nextPendingConnection** () to get a
        **QBluetoothSocket**  object to send and receive data over the
        connection.

        **See also** **nextPendingConnection** () and **hasPendingConnections**
        ().
        """
        ...
